/**
 * API Gateway API
 * API for the API Gateway service. Use this API to manage gateways, deployments, and related items.
For more information, see
[Overview of API Gateway](/iaas/Content/APIGateway/Concepts/apigatewayoverview.htm).

 * OpenAPI spec version: 20190501
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { ApiGatewayWaiter } from "./apigateway-waiter";
import { DeploymentWaiter } from "./deployment-waiter";
import { GatewayWaiter } from "./gateway-waiter";
import { WorkRequestsWaiter } from "./workrequests-waiter";
export declare enum ApiGatewayApiKeys {
}
export declare class ApiGatewayClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ApiGatewayWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
     * Creates a new ApiGatewayWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): ApiGatewayWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ApiGatewayWaiter;
    /**
     * Changes the API compartment.
     * @param ChangeApiCompartmentRequest
     * @return ChangeApiCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeApiCompartment(changeApiCompartmentRequest: requests.ChangeApiCompartmentRequest): Promise<responses.ChangeApiCompartmentResponse>;
    /**
     * Changes the certificate compartment.
     * @param ChangeCertificateCompartmentRequest
     * @return ChangeCertificateCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeCertificateCompartment(changeCertificateCompartmentRequest: requests.ChangeCertificateCompartmentRequest): Promise<responses.ChangeCertificateCompartmentResponse>;
    /**
     * Creates a new API.
     *
     * @param CreateApiRequest
     * @return CreateApiResponse
     * @throws OciError when an error occurs
     */
    createApi(createApiRequest: requests.CreateApiRequest): Promise<responses.CreateApiResponse>;
    /**
     * Creates a new Certificate.
     *
     * @param CreateCertificateRequest
     * @return CreateCertificateResponse
     * @throws OciError when an error occurs
     */
    createCertificate(createCertificateRequest: requests.CreateCertificateRequest): Promise<responses.CreateCertificateResponse>;
    /**
     * Deletes the API with the given identifier.
     * @param DeleteApiRequest
     * @return DeleteApiResponse
     * @throws OciError when an error occurs
     */
    deleteApi(deleteApiRequest: requests.DeleteApiRequest): Promise<responses.DeleteApiResponse>;
    /**
     * Deletes the certificate with the given identifier.
     * @param DeleteCertificateRequest
     * @return DeleteCertificateResponse
     * @throws OciError when an error occurs
     */
    deleteCertificate(deleteCertificateRequest: requests.DeleteCertificateRequest): Promise<responses.DeleteCertificateResponse>;
    /**
     * Gets an API by identifier.
     * @param GetApiRequest
     * @return GetApiResponse
     * @throws OciError when an error occurs
     */
    getApi(getApiRequest: requests.GetApiRequest): Promise<responses.GetApiResponse>;
    /**
     * Get the raw API content.
     * @param GetApiContentRequest
     * @return GetApiContentResponse
     * @throws OciError when an error occurs
     */
    getApiContent(getApiContentRequest: requests.GetApiContentRequest): Promise<responses.GetApiContentResponse>;
    /**
     * Gets an API Deployment specification by identifier.
     * @param GetApiDeploymentSpecificationRequest
     * @return GetApiDeploymentSpecificationResponse
     * @throws OciError when an error occurs
     */
    getApiDeploymentSpecification(getApiDeploymentSpecificationRequest: requests.GetApiDeploymentSpecificationRequest): Promise<responses.GetApiDeploymentSpecificationResponse>;
    /**
     * Gets the API validation results.
     * @param GetApiValidationsRequest
     * @return GetApiValidationsResponse
     * @throws OciError when an error occurs
     */
    getApiValidations(getApiValidationsRequest: requests.GetApiValidationsRequest): Promise<responses.GetApiValidationsResponse>;
    /**
     * Gets a certificate by identifier.
     * @param GetCertificateRequest
     * @return GetCertificateResponse
     * @throws OciError when an error occurs
     */
    getCertificate(getCertificateRequest: requests.GetCertificateRequest): Promise<responses.GetCertificateResponse>;
    /**
     * Returns a list of APIs.
     *
     * @param ListApisRequest
     * @return ListApisResponse
     * @throws OciError when an error occurs
     */
    listApis(listApisRequest: requests.ListApisRequest): Promise<responses.ListApisResponse>;
    /**
     * Returns a list of certificates.
     *
     * @param ListCertificatesRequest
     * @return ListCertificatesResponse
     * @throws OciError when an error occurs
     */
    listCertificates(listCertificatesRequest: requests.ListCertificatesRequest): Promise<responses.ListCertificatesResponse>;
    /**
     * Updates the API with the given identifier.
     * @param UpdateApiRequest
     * @return UpdateApiResponse
     * @throws OciError when an error occurs
     */
    updateApi(updateApiRequest: requests.UpdateApiRequest): Promise<responses.UpdateApiResponse>;
    /**
     * Updates a certificate with the given identifier
     * @param UpdateCertificateRequest
     * @return UpdateCertificateResponse
     * @throws OciError when an error occurs
     */
    updateCertificate(updateCertificateRequest: requests.UpdateCertificateRequest): Promise<responses.UpdateCertificateResponse>;
}
export declare enum DeploymentApiKeys {
}
export declare class DeploymentClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DeploymentWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
     * Creates a new DeploymentWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DeploymentWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DeploymentWaiter;
    /**
     * Changes the deployment compartment.
     * @param ChangeDeploymentCompartmentRequest
     * @return ChangeDeploymentCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeDeploymentCompartment(changeDeploymentCompartmentRequest: requests.ChangeDeploymentCompartmentRequest): Promise<responses.ChangeDeploymentCompartmentResponse>;
    /**
     * Creates a new deployment.
     *
     * @param CreateDeploymentRequest
     * @return CreateDeploymentResponse
     * @throws OciError when an error occurs
     */
    createDeployment(createDeploymentRequest: requests.CreateDeploymentRequest): Promise<responses.CreateDeploymentResponse>;
    /**
     * Deletes the deployment with the given identifier.
     * @param DeleteDeploymentRequest
     * @return DeleteDeploymentResponse
     * @throws OciError when an error occurs
     */
    deleteDeployment(deleteDeploymentRequest: requests.DeleteDeploymentRequest): Promise<responses.DeleteDeploymentResponse>;
    /**
     * Gets a deployment by identifier.
     * @param GetDeploymentRequest
     * @return GetDeploymentResponse
     * @throws OciError when an error occurs
     */
    getDeployment(getDeploymentRequest: requests.GetDeploymentRequest): Promise<responses.GetDeploymentResponse>;
    /**
     * Returns a list of deployments.
     *
     * @param ListDeploymentsRequest
     * @return ListDeploymentsResponse
     * @throws OciError when an error occurs
     */
    listDeployments(listDeploymentsRequest: requests.ListDeploymentsRequest): Promise<responses.ListDeploymentsResponse>;
    /**
     * Updates the deployment with the given identifier.
     * @param UpdateDeploymentRequest
     * @return UpdateDeploymentResponse
     * @throws OciError when an error occurs
     */
    updateDeployment(updateDeploymentRequest: requests.UpdateDeploymentRequest): Promise<responses.UpdateDeploymentResponse>;
}
export declare enum GatewayApiKeys {
}
export declare class GatewayClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": GatewayWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
     * Creates a new GatewayWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): GatewayWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): GatewayWaiter;
    /**
     * Changes the gateway compartment.
     * @param ChangeGatewayCompartmentRequest
     * @return ChangeGatewayCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeGatewayCompartment(changeGatewayCompartmentRequest: requests.ChangeGatewayCompartmentRequest): Promise<responses.ChangeGatewayCompartmentResponse>;
    /**
     * Creates a new gateway.
     *
     * @param CreateGatewayRequest
     * @return CreateGatewayResponse
     * @throws OciError when an error occurs
     */
    createGateway(createGatewayRequest: requests.CreateGatewayRequest): Promise<responses.CreateGatewayResponse>;
    /**
     * Deletes the gateway with the given identifier.
     * @param DeleteGatewayRequest
     * @return DeleteGatewayResponse
     * @throws OciError when an error occurs
     */
    deleteGateway(deleteGatewayRequest: requests.DeleteGatewayRequest): Promise<responses.DeleteGatewayResponse>;
    /**
     * Gets a gateway by identifier.
     * @param GetGatewayRequest
     * @return GetGatewayResponse
     * @throws OciError when an error occurs
     */
    getGateway(getGatewayRequest: requests.GetGatewayRequest): Promise<responses.GetGatewayResponse>;
    /**
     * Returns a list of gateways.
     *
     * @param ListGatewaysRequest
     * @return ListGatewaysResponse
     * @throws OciError when an error occurs
     */
    listGateways(listGatewaysRequest: requests.ListGatewaysRequest): Promise<responses.ListGatewaysResponse>;
    /**
     * Updates the gateway with the given identifier.
     * @param UpdateGatewayRequest
     * @return UpdateGatewayResponse
     * @throws OciError when an error occurs
     */
    updateGateway(updateGatewayRequest: requests.UpdateGatewayRequest): Promise<responses.UpdateGatewayResponse>;
}
export declare enum WorkRequestsApiKeys {
}
export declare class WorkRequestsClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": WorkRequestsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
     * Creates a new WorkRequestsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): WorkRequestsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): WorkRequestsWaiter;
    /**
     * Cancels the work request.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Gets the status of the work request with the given identifier.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a (paginated) list of errors for a given work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a (paginated) list of logs for a given work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
}
