/**
 * Autoscaling API
 * APIs for dynamically scaling Compute resources to meet application requirements. For more information about
autoscaling, see [Autoscaling](/Content/Compute/Tasks/autoscalinginstancepools.htm). For information about the
Compute service, see [Overview of the Compute Service](/Content/Compute/Concepts/computeoverview.htm).

**Note:** Autoscaling is not available in US Government Cloud tenancies. For more information, see
[Oracle Cloud Infrastructure US Government Cloud](/Content/General/Concepts/govoverview.htm).

 * OpenAPI spec version: 20181001
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
export declare enum AutoScalingApiKeys {
}
export declare class AutoScalingClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
       * Moves an autoscaling configuration into a different compartment within the same tenancy. For information
  * about moving resources between compartments, see
  * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
  * <p>
  When you move an autoscaling configuration to a different compartment, associated resources such as instance
  * pools are not moved.
  *
       * @param ChangeAutoScalingConfigurationCompartmentRequest
       * @return ChangeAutoScalingConfigurationCompartmentResponse
       * @throws OciError when an error occurs
       */
    changeAutoScalingConfigurationCompartment(changeAutoScalingConfigurationCompartmentRequest: requests.ChangeAutoScalingConfigurationCompartmentRequest): Promise<responses.ChangeAutoScalingConfigurationCompartmentResponse>;
    /**
     * Creates an autoscaling configuration.
     * @param CreateAutoScalingConfigurationRequest
     * @return CreateAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     */
    createAutoScalingConfiguration(createAutoScalingConfigurationRequest: requests.CreateAutoScalingConfigurationRequest): Promise<responses.CreateAutoScalingConfigurationResponse>;
    /**
     * Creates an autoscaling policy for the specified autoscaling configuration.
     *
     * @param CreateAutoScalingPolicyRequest
     * @return CreateAutoScalingPolicyResponse
     * @throws OciError when an error occurs
     */
    createAutoScalingPolicy(createAutoScalingPolicyRequest: requests.CreateAutoScalingPolicyRequest): Promise<responses.CreateAutoScalingPolicyResponse>;
    /**
     * Deletes an autoscaling configuration.
     * @param DeleteAutoScalingConfigurationRequest
     * @return DeleteAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     */
    deleteAutoScalingConfiguration(deleteAutoScalingConfigurationRequest: requests.DeleteAutoScalingConfigurationRequest): Promise<responses.DeleteAutoScalingConfigurationResponse>;
    /**
     * Deletes an autoscaling policy for the specified autoscaling configuration.
     * @param DeleteAutoScalingPolicyRequest
     * @return DeleteAutoScalingPolicyResponse
     * @throws OciError when an error occurs
     */
    deleteAutoScalingPolicy(deleteAutoScalingPolicyRequest: requests.DeleteAutoScalingPolicyRequest): Promise<responses.DeleteAutoScalingPolicyResponse>;
    /**
     * Gets information about the specified autoscaling configuration.
     * @param GetAutoScalingConfigurationRequest
     * @return GetAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     */
    getAutoScalingConfiguration(getAutoScalingConfigurationRequest: requests.GetAutoScalingConfigurationRequest): Promise<responses.GetAutoScalingConfigurationResponse>;
    /**
     * Gets information about the specified autoscaling policy in the specified autoscaling configuration.
     * @param GetAutoScalingPolicyRequest
     * @return GetAutoScalingPolicyResponse
     * @throws OciError when an error occurs
     */
    getAutoScalingPolicy(getAutoScalingPolicyRequest: requests.GetAutoScalingPolicyRequest): Promise<responses.GetAutoScalingPolicyResponse>;
    /**
     * Lists autoscaling configurations in the specifed compartment.
     *
     * @param ListAutoScalingConfigurationsRequest
     * @return ListAutoScalingConfigurationsResponse
     * @throws OciError when an error occurs
     */
    listAutoScalingConfigurations(listAutoScalingConfigurationsRequest: requests.ListAutoScalingConfigurationsRequest): Promise<responses.ListAutoScalingConfigurationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutoScalingConfigurationSummary objects
     * contained in responses from the listAutoScalingConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutoScalingConfigurations(request: requests.ListAutoScalingConfigurationsRequest): AsyncIterableIterator<models.AutoScalingConfigurationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutoScalingConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutoScalingConfigurationsResponses(request: requests.ListAutoScalingConfigurationsRequest): AsyncIterableIterator<responses.ListAutoScalingConfigurationsResponse>;
    /**
     * Lists the autoscaling policies in the specified autoscaling configuration.
     *
     * @param ListAutoScalingPoliciesRequest
     * @return ListAutoScalingPoliciesResponse
     * @throws OciError when an error occurs
     */
    listAutoScalingPolicies(listAutoScalingPoliciesRequest: requests.ListAutoScalingPoliciesRequest): Promise<responses.ListAutoScalingPoliciesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutoScalingPolicySummary objects
     * contained in responses from the listAutoScalingPolicies operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutoScalingPolicies(request: requests.ListAutoScalingPoliciesRequest): AsyncIterableIterator<models.AutoScalingPolicySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutoScalingPolicies operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutoScalingPoliciesResponses(request: requests.ListAutoScalingPoliciesRequest): AsyncIterableIterator<responses.ListAutoScalingPoliciesResponse>;
    /**
     * Updates certain fields on the specified autoscaling configuration, such as the name, the cooldown period,
     * and whether the autoscaling configuration is enabled.
     *
     * @param UpdateAutoScalingConfigurationRequest
     * @return UpdateAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     */
    updateAutoScalingConfiguration(updateAutoScalingConfigurationRequest: requests.UpdateAutoScalingConfigurationRequest): Promise<responses.UpdateAutoScalingConfigurationResponse>;
    /**
     * Updates an autoscaling policy in the specified autoscaling configuration.
     * @param UpdateAutoScalingPolicyRequest
     * @return UpdateAutoScalingPolicyResponse
     * @throws OciError when an error occurs
     */
    updateAutoScalingPolicy(updateAutoScalingPolicyRequest: requests.UpdateAutoScalingPolicyRequest): Promise<responses.UpdateAutoScalingPolicyResponse>;
}
