/**
 * Big Data Service API
 * API for the Big Data Service. Use this API to build, deploy, and manage fully elastic Big Data Service
build on Hadoop, Spark and Data Science distribution, which can be fully integrated with existing enterprise
data in Oracle Database and Oracle Applications..

 * OpenAPI spec version: 20190531
 * Contact: rahul.ra.arora@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
import { BdsWaiter } from "./bds-waiter";
export declare enum BdsApiKeys {
}
export declare class BdsClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": BdsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
     * Creates a new BdsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): BdsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): BdsWaiter;
    /**
     * Adds storage to existing worker nodes. The same amount of storage will be added to all workers.
     * No change will be made to already attached storage. Block Storage once added cannot be removed.
     *
     * @param AddBlockStorageRequest
     * @return AddBlockStorageResponse
     * @throws OciError when an error occurs
     */
    addBlockStorage(addBlockStorageRequest: requests.AddBlockStorageRequest): Promise<responses.AddBlockStorageResponse>;
    /**
     * Adds Cloud SQL to your cluster. This will add a query server node to the cluster
     * and create cell servers on all your worker nodes.
     *
     * @param AddCloudSqlRequest
     * @return AddCloudSqlResponse
     * @throws OciError when an error occurs
     */
    addCloudSql(addCloudSqlRequest: requests.AddCloudSqlRequest): Promise<responses.AddCloudSqlResponse>;
    /**
     * Add worker nodes to an existing cluster. The worker nodes added will be based on an identical shape
     * and have the same amount of attached block storage as other worker nodes in the cluster.
     *
     * @param AddWorkerNodesRequest
     * @return AddWorkerNodesResponse
     * @throws OciError when an error occurs
     */
    addWorkerNodes(addWorkerNodesRequest: requests.AddWorkerNodesRequest): Promise<responses.AddWorkerNodesResponse>;
    /**
     * Moves a BDS instance into a different compartment.
     *
     * @param ChangeBdsInstanceCompartmentRequest
     * @return ChangeBdsInstanceCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeBdsInstanceCompartment(changeBdsInstanceCompartmentRequest: requests.ChangeBdsInstanceCompartmentRequest): Promise<responses.ChangeBdsInstanceCompartmentResponse>;
    /**
     * Scale-up/down individial nodes (per role type) in the cluster. Customer can choose
     * arbitrarty VM_STANDARD shape to scale-up/down the instance. Only VM_STANDARD nodes
     * can be re-shaped.
     *
     * @param ChangeShapeRequest
     * @return ChangeShapeResponse
     * @throws OciError when an error occurs
     */
    changeShape(changeShapeRequest: requests.ChangeShapeRequest): Promise<responses.ChangeShapeResponse>;
    /**
     * Creates a new BDS instance.
     *
     * @param CreateBdsInstanceRequest
     * @return CreateBdsInstanceResponse
     * @throws OciError when an error occurs
     */
    createBdsInstance(createBdsInstanceRequest: requests.CreateBdsInstanceRequest): Promise<responses.CreateBdsInstanceResponse>;
    /**
     * Deletes a BDS instance by identifier
     * @param DeleteBdsInstanceRequest
     * @return DeleteBdsInstanceResponse
     * @throws OciError when an error occurs
     */
    deleteBdsInstance(deleteBdsInstanceRequest: requests.DeleteBdsInstanceRequest): Promise<responses.DeleteBdsInstanceResponse>;
    /**
     * Gets a BDS instance by identifier
     * @param GetBdsInstanceRequest
     * @return GetBdsInstanceResponse
     * @throws OciError when an error occurs
     */
    getBdsInstance(getBdsInstanceRequest: requests.GetBdsInstanceRequest): Promise<responses.GetBdsInstanceResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of BDS instances.
     *
     * @param ListBdsInstancesRequest
     * @return ListBdsInstancesResponse
     * @throws OciError when an error occurs
     */
    listBdsInstances(listBdsInstancesRequest: requests.ListBdsInstancesRequest): Promise<responses.ListBdsInstancesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BdsInstanceSummary objects
     * contained in responses from the listBdsInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBdsInstances(request: requests.ListBdsInstancesRequest): AsyncIterableIterator<models.BdsInstanceSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBdsInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBdsInstancesResponses(request: requests.ListBdsInstancesRequest): AsyncIterableIterator<responses.ListBdsInstancesResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<models.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<models.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequest objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<models.WorkRequest>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Remove Cloud SQL capability.
     *
     * @param RemoveCloudSqlRequest
     * @return RemoveCloudSqlResponse
     * @throws OciError when an error occurs
     */
    removeCloudSql(removeCloudSqlRequest: requests.RemoveCloudSqlRequest): Promise<responses.RemoveCloudSqlResponse>;
    /**
     * Restarts a single node of a BDS instance.
     *
     * @param RestartNodeRequest
     * @return RestartNodeResponse
     * @throws OciError when an error occurs
     */
    restartNode(restartNodeRequest: requests.RestartNodeRequest): Promise<responses.RestartNodeResponse>;
    /**
     * Update the BDS instance identified by the id
     * @param UpdateBdsInstanceRequest
     * @return UpdateBdsInstanceResponse
     * @throws OciError when an error occurs
     */
    updateBdsInstance(updateBdsInstanceRequest: requests.UpdateBdsInstanceRequest): Promise<responses.UpdateBdsInstanceResponse>;
}
