/**
 * Container Engine for Kubernetes API
 * API for the Container Engine for Kubernetes service. Use this API to build, deploy,
and manage cloud-native applications. For more information, see
[Overview of Container Engine for Kubernetes](/iaas/Content/ContEng/Concepts/contengoverview.htm).

 * OpenAPI spec version: 20180222
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
import { ContainerEngineWaiter } from "./containerengine-waiter";
export declare enum ContainerEngineApiKeys {
}
export declare class ContainerEngineClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ContainerEngineWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
     * Creates a new ContainerEngineWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): ContainerEngineWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ContainerEngineWaiter;
    /**
     * Create a new cluster.
     * @param CreateClusterRequest
     * @return CreateClusterResponse
     * @throws OciError when an error occurs
     */
    createCluster(createClusterRequest: requests.CreateClusterRequest): Promise<responses.CreateClusterResponse>;
    /**
     * Create the Kubeconfig YAML for a cluster.
     * @param CreateKubeconfigRequest
     * @return CreateKubeconfigResponse
     * @throws OciError when an error occurs
     */
    createKubeconfig(createKubeconfigRequest: requests.CreateKubeconfigRequest): Promise<responses.CreateKubeconfigResponse>;
    /**
     * Create a new node pool.
     * @param CreateNodePoolRequest
     * @return CreateNodePoolResponse
     * @throws OciError when an error occurs
     */
    createNodePool(createNodePoolRequest: requests.CreateNodePoolRequest): Promise<responses.CreateNodePoolResponse>;
    /**
     * Delete a cluster.
     * @param DeleteClusterRequest
     * @return DeleteClusterResponse
     * @throws OciError when an error occurs
     */
    deleteCluster(deleteClusterRequest: requests.DeleteClusterRequest): Promise<responses.DeleteClusterResponse>;
    /**
     * Delete a node pool.
     * @param DeleteNodePoolRequest
     * @return DeleteNodePoolResponse
     * @throws OciError when an error occurs
     */
    deleteNodePool(deleteNodePoolRequest: requests.DeleteNodePoolRequest): Promise<responses.DeleteNodePoolResponse>;
    /**
     * Cancel a work request that has not started.
     * @param DeleteWorkRequestRequest
     * @return DeleteWorkRequestResponse
     * @throws OciError when an error occurs
     */
    deleteWorkRequest(deleteWorkRequestRequest: requests.DeleteWorkRequestRequest): Promise<responses.DeleteWorkRequestResponse>;
    /**
     * Get the details of a cluster.
     * @param GetClusterRequest
     * @return GetClusterResponse
     * @throws OciError when an error occurs
     */
    getCluster(getClusterRequest: requests.GetClusterRequest): Promise<responses.GetClusterResponse>;
    /**
     * Get options available for clusters.
     * @param GetClusterOptionsRequest
     * @return GetClusterOptionsResponse
     * @throws OciError when an error occurs
     */
    getClusterOptions(getClusterOptionsRequest: requests.GetClusterOptionsRequest): Promise<responses.GetClusterOptionsResponse>;
    /**
     * Get the details of a node pool.
     * @param GetNodePoolRequest
     * @return GetNodePoolResponse
     * @throws OciError when an error occurs
     */
    getNodePool(getNodePoolRequest: requests.GetNodePoolRequest): Promise<responses.GetNodePoolResponse>;
    /**
     * Get options available for node pools.
     * @param GetNodePoolOptionsRequest
     * @return GetNodePoolOptionsResponse
     * @throws OciError when an error occurs
     */
    getNodePoolOptions(getNodePoolOptionsRequest: requests.GetNodePoolOptionsRequest): Promise<responses.GetNodePoolOptionsResponse>;
    /**
     * Get the details of a work request.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * List all the cluster objects in a compartment.
     * @param ListClustersRequest
     * @return ListClustersResponse
     * @throws OciError when an error occurs
     */
    listClusters(listClustersRequest: requests.ListClustersRequest): Promise<responses.ListClustersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ClusterSummary objects
     * contained in responses from the listClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllClusters(request: requests.ListClustersRequest): AsyncIterableIterator<models.ClusterSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllClustersResponses(request: requests.ListClustersRequest): AsyncIterableIterator<responses.ListClustersResponse>;
    /**
     * List all the node pools in a compartment, and optionally filter by cluster.
     * @param ListNodePoolsRequest
     * @return ListNodePoolsResponse
     * @throws OciError when an error occurs
     */
    listNodePools(listNodePoolsRequest: requests.ListNodePoolsRequest): Promise<responses.ListNodePoolsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NodePoolSummary objects
     * contained in responses from the listNodePools operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNodePools(request: requests.ListNodePoolsRequest): AsyncIterableIterator<models.NodePoolSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNodePools operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNodePoolsResponses(request: requests.ListNodePoolsRequest): AsyncIterableIterator<responses.ListNodePoolsResponse>;
    /**
     * Get the errors of a work request.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Get the logs of a work request.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * List all work requests in a compartment.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<models.WorkRequestSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Update the details of a cluster.
     * @param UpdateClusterRequest
     * @return UpdateClusterResponse
     * @throws OciError when an error occurs
     */
    updateCluster(updateClusterRequest: requests.UpdateClusterRequest): Promise<responses.UpdateClusterResponse>;
    /**
     * Update the details of a node pool.
     * @param UpdateNodePoolRequest
     * @return UpdateNodePoolResponse
     * @throws OciError when an error occurs
     */
    updateNodePool(updateNodePoolRequest: requests.UpdateNodePoolRequest): Promise<responses.UpdateNodePoolResponse>;
}
