/**
 * NoSQL Database API
 * The control plane API for NoSQL Database Cloud Service HTTPS
provides endpoints to perform NDCS operations, including creation
and deletion of tables and indexes; population and access of data
in tables; and access of table usage metrics.

 * OpenAPI spec version: 20190828
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { NosqlWaiter } from "./nosql-waiter";
export declare enum NosqlApiKeys {
}
export declare class NosqlClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": NosqlWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
     * Creates a new NosqlWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): NosqlWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): NosqlWaiter;
    /**
     * Change a table's compartment.
     * @param ChangeTableCompartmentRequest
     * @return ChangeTableCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeTableCompartment(changeTableCompartmentRequest: requests.ChangeTableCompartmentRequest): Promise<responses.ChangeTableCompartmentResponse>;
    /**
     * Create a new index on the table identified by tableNameOrId.
     * @param CreateIndexRequest
     * @return CreateIndexResponse
     * @throws OciError when an error occurs
     */
    createIndex(createIndexRequest: requests.CreateIndexRequest): Promise<responses.CreateIndexResponse>;
    /**
     * Create a new table.
     * @param CreateTableRequest
     * @return CreateTableResponse
     * @throws OciError when an error occurs
     */
    createTable(createTableRequest: requests.CreateTableRequest): Promise<responses.CreateTableResponse>;
    /**
     * Delete an index from the table identified by tableNameOrId.
     * @param DeleteIndexRequest
     * @return DeleteIndexResponse
     * @throws OciError when an error occurs
     */
    deleteIndex(deleteIndexRequest: requests.DeleteIndexRequest): Promise<responses.DeleteIndexResponse>;
    /**
     * Delete a single row from the table, by primary key.
     * @param DeleteRowRequest
     * @return DeleteRowResponse
     * @throws OciError when an error occurs
     */
    deleteRow(deleteRowRequest: requests.DeleteRowRequest): Promise<responses.DeleteRowResponse>;
    /**
     * Delete a table by tableNameOrId.
     * @param DeleteTableRequest
     * @return DeleteTableResponse
     * @throws OciError when an error occurs
     */
    deleteTable(deleteTableRequest: requests.DeleteTableRequest): Promise<responses.DeleteTableResponse>;
    /**
     * Cancel a work request operation with the given ID.
     * @param DeleteWorkRequestRequest
     * @return DeleteWorkRequestResponse
     * @throws OciError when an error occurs
     */
    deleteWorkRequest(deleteWorkRequestRequest: requests.DeleteWorkRequestRequest): Promise<responses.DeleteWorkRequestResponse>;
    /**
     * Get information about a single index.
     * @param GetIndexRequest
     * @return GetIndexResponse
     * @throws OciError when an error occurs
     */
    getIndex(getIndexRequest: requests.GetIndexRequest): Promise<responses.GetIndexResponse>;
    /**
     * Get a single row from the table by primary key.
     * @param GetRowRequest
     * @return GetRowResponse
     * @throws OciError when an error occurs
     */
    getRow(getRowRequest: requests.GetRowRequest): Promise<responses.GetRowResponse>;
    /**
     * Get table info by identifier.
     * @param GetTableRequest
     * @return GetTableResponse
     * @throws OciError when an error occurs
     */
    getTable(getTableRequest: requests.GetTableRequest): Promise<responses.GetTableResponse>;
    /**
     * Get the status of the work request with the given ID.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Get a list of indexes on a table.
     * @param ListIndexesRequest
     * @return ListIndexesResponse
     * @throws OciError when an error occurs
     */
    listIndexes(listIndexesRequest: requests.ListIndexesRequest): Promise<responses.ListIndexesResponse>;
    /**
     * Get table usage info.
     * @param ListTableUsageRequest
     * @return ListTableUsageResponse
     * @throws OciError when an error occurs
     */
    listTableUsage(listTableUsageRequest: requests.ListTableUsageRequest): Promise<responses.ListTableUsageResponse>;
    /**
     * Get a list of tables in a compartment.
     * @param ListTablesRequest
     * @return ListTablesResponse
     * @throws OciError when an error occurs
     */
    listTables(listTablesRequest: requests.ListTablesRequest): Promise<responses.ListTablesResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * List the work requests in a compartment.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Prepare a SQL statement for use in a query with variable substitution.
     *
     * @param PrepareStatementRequest
     * @return PrepareStatementResponse
     * @throws OciError when an error occurs
     */
    prepareStatement(prepareStatementRequest: requests.PrepareStatementRequest): Promise<responses.PrepareStatementResponse>;
    /**
     * Execute a SQL query.
     * @param QueryRequest
     * @return QueryResponse
     * @throws OciError when an error occurs
     */
    query(queryRequest: requests.QueryRequest): Promise<responses.QueryResponse>;
    /**
     * Check the syntax and return a brief summary of a SQL statement.
     *
     * @param SummarizeStatementRequest
     * @return SummarizeStatementResponse
     * @throws OciError when an error occurs
     */
    summarizeStatement(summarizeStatementRequest: requests.SummarizeStatementRequest): Promise<responses.SummarizeStatementResponse>;
    /**
     * Write a single row into the table.
     * @param UpdateRowRequest
     * @return UpdateRowResponse
     * @throws OciError when an error occurs
     */
    updateRow(updateRowRequest: requests.UpdateRowRequest): Promise<responses.UpdateRowResponse>;
    /**
     * Alter the table identified by tableNameOrId,
     * changing schema, limits, or tags
     *
     * @param UpdateTableRequest
     * @return UpdateTableResponse
     * @throws OciError when an error occurs
     */
    updateTable(updateTableRequest: requests.UpdateTableRequest): Promise<responses.UpdateTableResponse>;
}
