"use strict";
/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const common = require("oci-common");
const models = __importStar(require("./model"));
const oci_common_1 = require("oci-common");
const database_waiter_1 = require("./database-waiter");
const oci_common_2 = require("oci-common");
// ===============================================
// This file is autogenerated - Please do not edit
// ===============================================
var DatabaseApiKeys;
(function (DatabaseApiKeys) {
})(DatabaseApiKeys = exports.DatabaseApiKeys || (exports.DatabaseApiKeys = {}));
class DatabaseClient {
    constructor(params, clientConfiguration) {
        this["_endpoint"] = "";
        this["_defaultHeaders"] = {};
        this._circuitBreaker = null;
        const requestSigner = params.authenticationDetailsProvider
            ? new common.DefaultRequestSigner(params.authenticationDetailsProvider)
            : null;
        if (clientConfiguration) {
            this._clientConfiguration = clientConfiguration;
            this._circuitBreaker = clientConfiguration.circuitBreaker
                ? clientConfiguration.circuitBreaker.circuit
                : null;
        }
        this._httpClient =
            params.httpClient || new common.FetchHttpClient(requestSigner, this._circuitBreaker);
        if (params.authenticationDetailsProvider &&
            common.isRegionProvider(params.authenticationDetailsProvider)) {
            const provider = params.authenticationDetailsProvider;
            if (provider.getRegion()) {
                this.region = provider.getRegion();
            }
        }
    }
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint() {
        return this._endpoint;
    }
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint) {
        this._endpoint = endpoint;
        this._endpoint = this._endpoint + "/20160918";
        if (this.logger)
            this.logger.info(`DatabaseClient endpoint set to ${this._endpoint}`);
    }
    get logger() {
        return common.LOG.logger;
    }
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region) {
        this.endpoint = common.EndpointBuilder.createEndpointFromRegion(DatabaseClient.serviceEndpointTemplate, region);
    }
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId) {
        this.endpoint = common.EndpointBuilder.createEndpointFromRegionId(DatabaseClient.serviceEndpointTemplate, regionId);
    }
    /**
     * Creates a new DatabaseWaiter for resources for this service.
     *
     * @param workRequestClient The work request service client used to query for work request status
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(workRequestClient, config) {
        this._waiters = new database_waiter_1.DatabaseWaiter(this, workRequestClient, config);
        return this._waiters;
    }
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters() {
        if (this._waiters) {
            return this._waiters;
        }
        throw Error("Waiters do not exist. Please create waiters.");
    }
    /**
     * Activates the specified Exadata Cloud@Customer infrastructure.
     * @param ActivateExadataInfrastructureRequest
     * @return ActivateExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    activateExadataInfrastructure(activateExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#activateExadataInfrastructure.");
            const pathParams = {
                "{exadataInfrastructureId}": activateExadataInfrastructureRequest.exadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": activateExadataInfrastructureRequest.opcRequestId,
                "opc-retry-token": activateExadataInfrastructureRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/actions/activate",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(activateExadataInfrastructureRequest.activateExadataInfrastructureDetails, "ActivateExadataInfrastructureDetails", models.ActivateExadataInfrastructureDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, activateExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "exadataInfrastructure",
                    bodyModel: "model.ExadataInfrastructure",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Initiates a data refresh for an Autonomous Database refreshable clone. Data is refreshed from the source database to the point of a specified timestamp.
     *
     * @param AutonomousDatabaseManualRefreshRequest
     * @return AutonomousDatabaseManualRefreshResponse
     * @throws OciError when an error occurs
     */
    autonomousDatabaseManualRefresh(autonomousDatabaseManualRefreshRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#autonomousDatabaseManualRefresh.");
            const pathParams = {
                "{autonomousDatabaseId}": autonomousDatabaseManualRefreshRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": autonomousDatabaseManualRefreshRequest.ifMatch,
                "opc-retry-token": autonomousDatabaseManualRefreshRequest.opcRetryToken,
                "opc-request-id": autonomousDatabaseManualRefreshRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/refresh",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(autonomousDatabaseManualRefreshRequest.autonomousDatabaseManualRefreshDetails, "AutonomousDatabaseManualRefreshDetails", models.AutonomousDatabaseManualRefreshDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, autonomousDatabaseManualRefreshRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Move the Autonomous Container Database and its dependent resources to the specified compartment.
     * For more information about moving Autonomous Container Databases, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * @param ChangeAutonomousContainerDatabaseCompartmentRequest
     * @return ChangeAutonomousContainerDatabaseCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeAutonomousContainerDatabaseCompartment(changeAutonomousContainerDatabaseCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeAutonomousContainerDatabaseCompartment.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": changeAutonomousContainerDatabaseCompartmentRequest.autonomousContainerDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeAutonomousContainerDatabaseCompartmentRequest.opcRetryToken,
                "opc-request-id": changeAutonomousContainerDatabaseCompartmentRequest.opcRequestId,
                "if-match": changeAutonomousContainerDatabaseCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeAutonomousContainerDatabaseCompartmentRequest.changeCompartmentDetails, "ChangeCompartmentDetails", models.ChangeCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeAutonomousContainerDatabaseCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Move the Autonomous Database and its dependent resources to the specified compartment.
     * For more information about moving Autonomous Databases, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * @param ChangeAutonomousDatabaseCompartmentRequest
     * @return ChangeAutonomousDatabaseCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeAutonomousDatabaseCompartment(changeAutonomousDatabaseCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeAutonomousDatabaseCompartment.");
            const pathParams = {
                "{autonomousDatabaseId}": changeAutonomousDatabaseCompartmentRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeAutonomousDatabaseCompartmentRequest.opcRetryToken,
                "opc-request-id": changeAutonomousDatabaseCompartmentRequest.opcRequestId,
                "if-match": changeAutonomousDatabaseCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeAutonomousDatabaseCompartmentRequest.changeCompartmentDetails, "ChangeCompartmentDetails", models.ChangeCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeAutonomousDatabaseCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Moves the Autonomous Exadata Infrastructure resource and its dependent resources to the specified compartment.
     * For more information, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * @param ChangeAutonomousExadataInfrastructureCompartmentRequest
     * @return ChangeAutonomousExadataInfrastructureCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeAutonomousExadataInfrastructureCompartment(changeAutonomousExadataInfrastructureCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeAutonomousExadataInfrastructureCompartment.");
            const pathParams = {
                "{autonomousExadataInfrastructureId}": changeAutonomousExadataInfrastructureCompartmentRequest.autonomousExadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeAutonomousExadataInfrastructureCompartmentRequest.opcRetryToken,
                "opc-request-id": changeAutonomousExadataInfrastructureCompartmentRequest.opcRequestId,
                "if-match": changeAutonomousExadataInfrastructureCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousExadataInfrastructures/{autonomousExadataInfrastructureId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeAutonomousExadataInfrastructureCompartmentRequest.changeCompartmentDetails, "ChangeCompartmentDetails", models.ChangeCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeAutonomousExadataInfrastructureCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * To move an Autonomous VM cluster and its dependent resources to another compartment, use the
     * {@link #changeAutonomousVmClusterCompartment(ChangeAutonomousVmClusterCompartmentRequest) changeAutonomousVmClusterCompartment} operation.
     *
     * @param ChangeAutonomousVmClusterCompartmentRequest
     * @return ChangeAutonomousVmClusterCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeAutonomousVmClusterCompartment(changeAutonomousVmClusterCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeAutonomousVmClusterCompartment.");
            const pathParams = {
                "{autonomousVmClusterId}": changeAutonomousVmClusterCompartmentRequest.autonomousVmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeAutonomousVmClusterCompartmentRequest.opcRetryToken,
                "opc-request-id": changeAutonomousVmClusterCompartmentRequest.opcRequestId,
                "if-match": changeAutonomousVmClusterCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousVmClusters/{autonomousVmClusterId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeAutonomousVmClusterCompartmentRequest.changeAutonomousVmClusterCompartmentDetails, "ChangeAutonomousVmClusterCompartmentDetails", models.ChangeAutonomousVmClusterCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeAutonomousVmClusterCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Move the backup destination and its dependent resources to the specified compartment.
     * For more information, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * @param ChangeBackupDestinationCompartmentRequest
     * @return ChangeBackupDestinationCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeBackupDestinationCompartment(changeBackupDestinationCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeBackupDestinationCompartment.");
            const pathParams = {
                "{backupDestinationId}": changeBackupDestinationCompartmentRequest.backupDestinationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeBackupDestinationCompartmentRequest.opcRetryToken,
                "opc-request-id": changeBackupDestinationCompartmentRequest.opcRequestId,
                "if-match": changeBackupDestinationCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/backupDestinations/{backupDestinationId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeBackupDestinationCompartmentRequest.changeCompartmentDetails, "ChangeCompartmentDetails", models.ChangeCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeBackupDestinationCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * To move a cloud Exadata infrastructure resource and its dependent resources to another compartment, use the
     * {@link #changeCloudExadataInfrastructureCompartment(ChangeCloudExadataInfrastructureCompartmentRequest) changeCloudExadataInfrastructureCompartment} operation.
     *
     * @param ChangeCloudExadataInfrastructureCompartmentRequest
     * @return ChangeCloudExadataInfrastructureCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeCloudExadataInfrastructureCompartment(changeCloudExadataInfrastructureCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeCloudExadataInfrastructureCompartment.");
            const pathParams = {
                "{cloudExadataInfrastructureId}": changeCloudExadataInfrastructureCompartmentRequest.cloudExadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeCloudExadataInfrastructureCompartmentRequest.opcRetryToken,
                "opc-request-id": changeCloudExadataInfrastructureCompartmentRequest.opcRequestId,
                "if-match": changeCloudExadataInfrastructureCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudExadataInfrastructures/{cloudExadataInfrastructureId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeCloudExadataInfrastructureCompartmentRequest.changeCloudExadataInfrastructureCompartmentDetails, "ChangeCloudExadataInfrastructureCompartmentDetails", models.ChangeCloudExadataInfrastructureCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeCloudExadataInfrastructureCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * To move a cloud VM cluster and its dependent resources to another compartment, use the
     * {@link #changeCloudVmClusterCompartment(ChangeCloudVmClusterCompartmentRequest) changeCloudVmClusterCompartment} operation.
     *
     * @param ChangeCloudVmClusterCompartmentRequest
     * @return ChangeCloudVmClusterCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeCloudVmClusterCompartment(changeCloudVmClusterCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeCloudVmClusterCompartment.");
            const pathParams = {
                "{cloudVmClusterId}": changeCloudVmClusterCompartmentRequest.cloudVmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeCloudVmClusterCompartmentRequest.opcRetryToken,
                "opc-request-id": changeCloudVmClusterCompartmentRequest.opcRequestId,
                "if-match": changeCloudVmClusterCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters/{cloudVmClusterId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeCloudVmClusterCompartmentRequest.changeCloudVmClusterCompartmentDetails, "ChangeCloudVmClusterCompartmentDetails", models.ChangeCloudVmClusterCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeCloudVmClusterCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Move the Database Software Image and its dependent resources to the specified compartment.
     * For more information about moving Databse Software Images, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * @param ChangeDatabaseSoftwareImageCompartmentRequest
     * @return ChangeDatabaseSoftwareImageCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeDatabaseSoftwareImageCompartment(changeDatabaseSoftwareImageCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeDatabaseSoftwareImageCompartment.");
            const pathParams = {
                "{databaseSoftwareImageId}": changeDatabaseSoftwareImageCompartmentRequest.databaseSoftwareImageId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeDatabaseSoftwareImageCompartmentRequest.opcRetryToken,
                "opc-request-id": changeDatabaseSoftwareImageCompartmentRequest.opcRequestId,
                "if-match": changeDatabaseSoftwareImageCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databaseSoftwareImages/{databaseSoftwareImageId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeDatabaseSoftwareImageCompartmentRequest.changeCompartmentDetails, "ChangeCompartmentDetails", models.ChangeCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeDatabaseSoftwareImageCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Move the DB system and its dependent resources to the specified compartment.
     * For more information about moving DB systems, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * @param ChangeDbSystemCompartmentRequest
     * @return ChangeDbSystemCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeDbSystemCompartment(changeDbSystemCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeDbSystemCompartment.");
            const pathParams = {
                "{dbSystemId}": changeDbSystemCompartmentRequest.dbSystemId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeDbSystemCompartmentRequest.opcRetryToken,
                "opc-request-id": changeDbSystemCompartmentRequest.opcRequestId,
                "if-match": changeDbSystemCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeDbSystemCompartmentRequest.changeCompartmentDetails, "ChangeCompartmentDetails", models.ChangeCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeDbSystemCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * To move an Exadata Cloud@Customer infrastructure resource and its dependent resources to another compartment, use the
     * {@link #changeExadataInfrastructureCompartment(ChangeExadataInfrastructureCompartmentRequest) changeExadataInfrastructureCompartment} operation.
     *
     * @param ChangeExadataInfrastructureCompartmentRequest
     * @return ChangeExadataInfrastructureCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeExadataInfrastructureCompartment(changeExadataInfrastructureCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeExadataInfrastructureCompartment.");
            const pathParams = {
                "{exadataInfrastructureId}": changeExadataInfrastructureCompartmentRequest.exadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeExadataInfrastructureCompartmentRequest.opcRetryToken,
                "opc-request-id": changeExadataInfrastructureCompartmentRequest.opcRequestId,
                "if-match": changeExadataInfrastructureCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeExadataInfrastructureCompartmentRequest.changeExadataInfrastructureCompartmentDetails, "ChangeExadataInfrastructureCompartmentDetails", models.ChangeExadataInfrastructureCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeExadataInfrastructureCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Move the key store resource to the specified compartment.
     * For more information about moving key stores, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * @param ChangeKeyStoreCompartmentRequest
     * @return ChangeKeyStoreCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeKeyStoreCompartment(changeKeyStoreCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeKeyStoreCompartment.");
            const pathParams = {
                "{keyStoreId}": changeKeyStoreCompartmentRequest.keyStoreId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeKeyStoreCompartmentRequest.opcRetryToken,
                "opc-request-id": changeKeyStoreCompartmentRequest.opcRequestId,
                "if-match": changeKeyStoreCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/keyStores/{keyStoreId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeKeyStoreCompartmentRequest.changeKeyStoreCompartmentDetails, "ChangeKeyStoreCompartmentDetails", models.ChangeKeyStoreCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeKeyStoreCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * To move an Exadata Cloud@Customer VM cluster and its dependent resources to another compartment, use the
     * {@link #changeVmClusterCompartment(ChangeVmClusterCompartmentRequest) changeVmClusterCompartment} operation.
     *
     * @param ChangeVmClusterCompartmentRequest
     * @return ChangeVmClusterCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeVmClusterCompartment(changeVmClusterCompartmentRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#changeVmClusterCompartment.");
            const pathParams = {
                "{vmClusterId}": changeVmClusterCompartmentRequest.vmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": changeVmClusterCompartmentRequest.opcRetryToken,
                "opc-request-id": changeVmClusterCompartmentRequest.opcRequestId,
                "if-match": changeVmClusterCompartmentRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/vmClusters/{vmClusterId}/actions/changeCompartment",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(changeVmClusterCompartmentRequest.changeVmClusterCompartmentDetails, "ChangeVmClusterCompartmentDetails", models.ChangeVmClusterCompartmentDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, changeVmClusterCompartmentRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Changes the status of the standalone backup resource to `ACTIVE` after the backup is created from the on-premises database and placed in Oracle Cloud Infrastructure Object Storage.
     * <p>
     **Note:** This API is used by an Oracle Cloud Infrastructure Python script that is packaged with the Oracle Cloud Infrastructure CLI. Oracle recommends that you use the script instead using the API directly. See [Migrating an On-Premises Database to Oracle Cloud Infrastructure by Creating a Backup in the Cloud](https://docs.cloud.oracle.com/Content/Database/Tasks/mig-onprembackup.htm) for more information.
     *
     * @param CompleteExternalBackupJobRequest
     * @return CompleteExternalBackupJobResponse
     * @throws OciError when an error occurs
     */
    completeExternalBackupJob(completeExternalBackupJobRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#completeExternalBackupJob.");
            const pathParams = {
                "{backupId}": completeExternalBackupJobRequest.backupId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": completeExternalBackupJobRequest.ifMatch,
                "opc-retry-token": completeExternalBackupJobRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/externalBackupJobs/{backupId}/actions/complete",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(completeExternalBackupJobRequest.completeExternalBackupJobDetails, "CompleteExternalBackupJobDetails", models.CompleteExternalBackupJobDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, completeExternalBackupJobRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "externalBackupJob",
                    bodyModel: "model.ExternalBackupJob",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates an Autonomous Container Database in the specified Autonomous Exadata Infrastructure.
     *
     * @param CreateAutonomousContainerDatabaseRequest
     * @return CreateAutonomousContainerDatabaseResponse
     * @throws OciError when an error occurs
     */
    createAutonomousContainerDatabase(createAutonomousContainerDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createAutonomousContainerDatabase.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createAutonomousContainerDatabaseRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createAutonomousContainerDatabaseRequest.createAutonomousContainerDatabaseDetails, "CreateAutonomousContainerDatabaseDetails", models.CreateAutonomousContainerDatabaseDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createAutonomousContainerDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousContainerDatabase",
                    bodyModel: "model.AutonomousContainerDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * **Deprecated.** To create a new Autonomous Data Warehouse, use the {@link #createAutonomousDatabase(CreateAutonomousDatabaseRequest) createAutonomousDatabase} operation and specify `DW` as the workload type.
     *
     * @param CreateAutonomousDataWarehouseRequest
     * @return CreateAutonomousDataWarehouseResponse
     * @throws OciError when an error occurs
     */
    createAutonomousDataWarehouse(createAutonomousDataWarehouseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createAutonomousDataWarehouse.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createAutonomousDataWarehouseRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouses",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createAutonomousDataWarehouseRequest.createAutonomousDataWarehouseDetails, "CreateAutonomousDataWarehouseDetails", models.CreateAutonomousDataWarehouseDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createAutonomousDataWarehouseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDataWarehouse",
                    bodyModel: "model.AutonomousDataWarehouse",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * **Deprecated.** To create a new Autonomous Data Warehouse backup for a specified database, use the {@link #createAutonomousDatabaseBackup(CreateAutonomousDatabaseBackupRequest) createAutonomousDatabaseBackup} operation.
     *
     * @param CreateAutonomousDataWarehouseBackupRequest
     * @return CreateAutonomousDataWarehouseBackupResponse
     * @throws OciError when an error occurs
     */
    createAutonomousDataWarehouseBackup(createAutonomousDataWarehouseBackupRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createAutonomousDataWarehouseBackup.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createAutonomousDataWarehouseBackupRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouseBackups",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createAutonomousDataWarehouseBackupRequest.createAutonomousDataWarehouseBackupDetails, "CreateAutonomousDataWarehouseBackupDetails", models.CreateAutonomousDataWarehouseBackupDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createAutonomousDataWarehouseBackupRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDataWarehouseBackup",
                    bodyModel: "model.AutonomousDataWarehouseBackup",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new Autonomous Database.
     *
     * @param CreateAutonomousDatabaseRequest
     * @return CreateAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     */
    createAutonomousDatabase(createAutonomousDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createAutonomousDatabase.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createAutonomousDatabaseRequest.opcRetryToken,
                "opc-request-id": createAutonomousDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createAutonomousDatabaseRequest.createAutonomousDatabaseDetails, "CreateAutonomousDatabaseBase", models.CreateAutonomousDatabaseBase.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createAutonomousDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new Autonomous Database backup for the specified database based on the provided request parameters.
     *
     * @param CreateAutonomousDatabaseBackupRequest
     * @return CreateAutonomousDatabaseBackupResponse
     * @throws OciError when an error occurs
     */
    createAutonomousDatabaseBackup(createAutonomousDatabaseBackupRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createAutonomousDatabaseBackup.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createAutonomousDatabaseBackupRequest.opcRetryToken,
                "opc-request-id": createAutonomousDatabaseBackupRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabaseBackups",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createAutonomousDatabaseBackupRequest.createAutonomousDatabaseBackupDetails, "CreateAutonomousDatabaseBackupDetails", models.CreateAutonomousDatabaseBackupDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createAutonomousDatabaseBackupRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabaseBackup",
                    bodyModel: "model.AutonomousDatabaseBackup",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates an Autonomous VM cluster for Exadata Cloud@Customer.
     *
     * @param CreateAutonomousVmClusterRequest
     * @return CreateAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     */
    createAutonomousVmCluster(createAutonomousVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createAutonomousVmCluster.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createAutonomousVmClusterRequest.opcRetryToken,
                "opc-request-id": createAutonomousVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousVmClusters",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createAutonomousVmClusterRequest.createAutonomousVmClusterDetails, "CreateAutonomousVmClusterDetails", models.CreateAutonomousVmClusterDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createAutonomousVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousVmCluster",
                    bodyModel: "model.AutonomousVmCluster",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new backup in the specified database based on the request parameters you provide. If you previously used RMAN or dbcli to configure backups and then you switch to using the Console or the API for backups, a new backup configuration is created and associated with your database. This means that you can no longer rely on your previously configured unmanaged backups to work.
     *
     * @param CreateBackupRequest
     * @return CreateBackupResponse
     * @throws OciError when an error occurs
     */
    createBackup(createBackupRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createBackup.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createBackupRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/backups",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createBackupRequest.createBackupDetails, "CreateBackupDetails", models.CreateBackupDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createBackupRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "backup",
                    bodyModel: "model.Backup",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a backup destination in an Exadata Cloud@Customer system.
     *
     * @param CreateBackupDestinationRequest
     * @return CreateBackupDestinationResponse
     * @throws OciError when an error occurs
     */
    createBackupDestination(createBackupDestinationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createBackupDestination.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createBackupDestinationRequest.opcRetryToken,
                "opc-request-id": createBackupDestinationRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/backupDestinations",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createBackupDestinationRequest.createBackupDestinationDetails, "CreateBackupDestinationDetails", models.CreateBackupDestinationDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createBackupDestinationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "backupDestination",
                    bodyModel: "model.BackupDestination",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a cloud Exadata infrastructure resource.
     * @param CreateCloudExadataInfrastructureRequest
     * @return CreateCloudExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    createCloudExadataInfrastructure(createCloudExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createCloudExadataInfrastructure.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createCloudExadataInfrastructureRequest.opcRetryToken,
                "opc-request-id": createCloudExadataInfrastructureRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudExadataInfrastructures",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createCloudExadataInfrastructureRequest.createCloudExadataInfrastructureDetails, "CreateCloudExadataInfrastructureDetails", models.CreateCloudExadataInfrastructureDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createCloudExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "cloudExadataInfrastructure",
                    bodyModel: "model.CloudExadataInfrastructure",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a cloud VM cluster.
     *
     * @param CreateCloudVmClusterRequest
     * @return CreateCloudVmClusterResponse
     * @throws OciError when an error occurs
     */
    createCloudVmCluster(createCloudVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createCloudVmCluster.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createCloudVmClusterRequest.opcRetryToken,
                "opc-request-id": createCloudVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createCloudVmClusterRequest.createCloudVmClusterDetails, "CreateCloudVmClusterDetails", models.CreateCloudVmClusterDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createCloudVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "cloudVmCluster",
                    bodyModel: "model.CloudVmCluster",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new console connection to the specified database node.
     * After the console connection has been created and is available,
     * you connect to the console using SSH.
     *
     * @param CreateConsoleConnectionRequest
     * @return CreateConsoleConnectionResponse
     * @throws OciError when an error occurs
     */
    createConsoleConnection(createConsoleConnectionRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createConsoleConnection.");
            const pathParams = {
                "{dbNodeId}": createConsoleConnectionRequest.dbNodeId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createConsoleConnectionRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbNodes/{dbNodeId}/consoleConnections",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createConsoleConnectionRequest.createConsoleConnectionDetails, "CreateConsoleConnectionDetails", models.CreateConsoleConnectionDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createConsoleConnectionRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "consoleConnection",
                    bodyModel: "model.ConsoleConnection",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
       * Creates a new Data Guard association.  A Data Guard association represents the replication relationship between the
  * specified database and a peer database. For more information, see [Using Oracle Data Guard](https://docs.cloud.oracle.com/Content/Database/Tasks/usingdataguard.htm).
  * <p>
  All Oracle Cloud Infrastructure resources, including Data Guard associations, get an Oracle-assigned, unique ID
  * called an Oracle Cloud Identifier (OCID). When you create a resource, you can find its OCID in the response.
  * You can also retrieve a resource's OCID by using a List API operation on that resource type, or by viewing the
  * resource in the Console. For more information, see
  * [Resource Identifiers](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
  *
       * @param CreateDataGuardAssociationRequest
       * @return CreateDataGuardAssociationResponse
       * @throws OciError when an error occurs
       */
    createDataGuardAssociation(createDataGuardAssociationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createDataGuardAssociation.");
            const pathParams = {
                "{databaseId}": createDataGuardAssociationRequest.databaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createDataGuardAssociationRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}/dataGuardAssociations",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createDataGuardAssociationRequest.createDataGuardAssociationDetails, "CreateDataGuardAssociationDetails", models.CreateDataGuardAssociationDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createDataGuardAssociationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dataGuardAssociation",
                    bodyModel: "model.DataGuardAssociation",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new database in the specified Database Home. If the database version is provided, it must match the version of the Database Home. Applies to Exadata and Exadata Cloud@Customer systems.
     *
     * @param CreateDatabaseRequest
     * @return CreateDatabaseResponse
     * @throws OciError when an error occurs
     */
    createDatabase(createDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createDatabase.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createDatabaseRequest.opcRetryToken,
                "opc-request-id": createDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createDatabaseRequest.createNewDatabaseDetails, "CreateDatabaseBase", models.CreateDatabaseBase.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "database",
                    bodyModel: "model.Database",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * create database software image in the specified compartment.
     *
     * @param CreateDatabaseSoftwareImageRequest
     * @return CreateDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     */
    createDatabaseSoftwareImage(createDatabaseSoftwareImageRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createDatabaseSoftwareImage.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createDatabaseSoftwareImageRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databaseSoftwareImages",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createDatabaseSoftwareImageRequest.createDatabaseSoftwareImageDetails, "CreateDatabaseSoftwareImageDetails", models.CreateDatabaseSoftwareImageDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createDatabaseSoftwareImageRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "databaseSoftwareImage",
                    bodyModel: "model.DatabaseSoftwareImage",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new Database Home in the specified database system based on the request parameters you provide. Applies to bare metal DB systems, Exadata systems, and Exadata Cloud@Customer systems.
     *
     * @param CreateDbHomeRequest
     * @return CreateDbHomeResponse
     * @throws OciError when an error occurs
     */
    createDbHome(createDbHomeRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createDbHome.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createDbHomeRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbHomes",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createDbHomeRequest.createDbHomeWithDbSystemIdDetails, "CreateDbHomeBase", models.CreateDbHomeBase.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createDbHomeRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dbHome",
                    bodyModel: "model.DbHome",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates Exadata Cloud@Customer infrastructure.
     * @param CreateExadataInfrastructureRequest
     * @return CreateExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    createExadataInfrastructure(createExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createExadataInfrastructure.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createExadataInfrastructureRequest.opcRetryToken,
                "opc-request-id": createExadataInfrastructureRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createExadataInfrastructureRequest.createExadataInfrastructureDetails, "CreateExadataInfrastructureDetails", models.CreateExadataInfrastructureDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "exadataInfrastructure",
                    bodyModel: "model.ExadataInfrastructure",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new backup resource and returns the information the caller needs to back up an on-premises Oracle Database to Oracle Cloud Infrastructure.
     * <p>
     **Note:** This API is used by an Oracle Cloud Infrastructure Python script that is packaged with the Oracle Cloud Infrastructure CLI. Oracle recommends that you use the script instead using the API directly. See [Migrating an On-Premises Database to Oracle Cloud Infrastructure by Creating a Backup in the Cloud](https://docs.cloud.oracle.com/Content/Database/Tasks/mig-onprembackup.htm) for more information.
     *
     * @param CreateExternalBackupJobRequest
     * @return CreateExternalBackupJobResponse
     * @throws OciError when an error occurs
     */
    createExternalBackupJob(createExternalBackupJobRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createExternalBackupJob.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createExternalBackupJobRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/externalBackupJobs",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createExternalBackupJobRequest.createExternalBackupJobDetails, "CreateExternalBackupJobDetails", models.CreateExternalBackupJobDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createExternalBackupJobRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "externalBackupJob",
                    bodyModel: "model.ExternalBackupJob",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a Key Store.
     *
     * @param CreateKeyStoreRequest
     * @return CreateKeyStoreResponse
     * @throws OciError when an error occurs
     */
    createKeyStore(createKeyStoreRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createKeyStore.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createKeyStoreRequest.opcRetryToken,
                "opc-request-id": createKeyStoreRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/keyStores",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createKeyStoreRequest.createKeyStoreDetails, "CreateKeyStoreDetails", models.CreateKeyStoreDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createKeyStoreRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "keyStore",
                    bodyModel: "model.KeyStore",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates an Exadata Cloud@Customer VM cluster.
     *
     * @param CreateVmClusterRequest
     * @return CreateVmClusterResponse
     * @throws OciError when an error occurs
     */
    createVmCluster(createVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createVmCluster.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createVmClusterRequest.opcRetryToken,
                "opc-request-id": createVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/vmClusters",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createVmClusterRequest.createVmClusterDetails, "CreateVmClusterDetails", models.CreateVmClusterDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "vmCluster",
                    bodyModel: "model.VmCluster",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates the Exadata Cloud@Customer VM cluster network.
     *
     * @param CreateVmClusterNetworkRequest
     * @return CreateVmClusterNetworkResponse
     * @throws OciError when an error occurs
     */
    createVmClusterNetwork(createVmClusterNetworkRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#createVmClusterNetwork.");
            const pathParams = {
                "{exadataInfrastructureId}": createVmClusterNetworkRequest.exadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": createVmClusterNetworkRequest.opcRetryToken,
                "opc-request-id": createVmClusterNetworkRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/vmClusterNetworks",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(createVmClusterNetworkRequest.vmClusterNetworkDetails, "VmClusterNetworkDetails", models.VmClusterNetworkDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, createVmClusterNetworkRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "vmClusterNetwork",
                    bodyModel: "model.VmClusterNetwork",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Performs one of the following power actions on the specified DB node:
     * - start - power on
     * - stop - power off
     * - softreset - ACPI shutdown and power on
     * - reset - power off and power on
     * <p>
     **Note:** Stopping a node affects billing differently, depending on the type of DB system:
     * *Bare metal and Exadata systems* - The _stop_ state has no effect on the resources you consume.
     * Billing continues for DB nodes that you stop, and related resources continue
     * to apply against any relevant quotas. You must terminate the DB system
     * ({@link #terminateDbSystem(TerminateDbSystemRequest) terminateDbSystem})
     * to remove its resources from billing and quotas.
     * *Virtual machine DB systems* - Stopping a node stops billing for all OCPUs associated with that node, and billing resumes when you restart the node.
     *
     * @param DbNodeActionRequest
     * @return DbNodeActionResponse
     * @throws OciError when an error occurs
     */
    dbNodeAction(dbNodeActionRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#dbNodeAction.");
            const pathParams = {
                "{dbNodeId}": dbNodeActionRequest.dbNodeId
            };
            const queryParams = {
                "action": dbNodeActionRequest.action
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": dbNodeActionRequest.opcRetryToken,
                "if-match": dbNodeActionRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbNodes/{dbNodeId}",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, dbNodeActionRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dbNode",
                    bodyModel: "model.DbNode",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * **Deprecated.** To delete an Autonomous Data Warehouse, use the {@link #deleteAutonomousDatabase(DeleteAutonomousDatabaseRequest) deleteAutonomousDatabase} operation.
     *
     * @param DeleteAutonomousDataWarehouseRequest
     * @return DeleteAutonomousDataWarehouseResponse
     * @throws OciError when an error occurs
     */
    deleteAutonomousDataWarehouse(deleteAutonomousDataWarehouseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteAutonomousDataWarehouse.");
            const pathParams = {
                "{autonomousDataWarehouseId}": deleteAutonomousDataWarehouseRequest.autonomousDataWarehouseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteAutonomousDataWarehouseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouses/{autonomousDataWarehouseId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteAutonomousDataWarehouseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes the specified Autonomous Database.
     *
     * @param DeleteAutonomousDatabaseRequest
     * @return DeleteAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     */
    deleteAutonomousDatabase(deleteAutonomousDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteAutonomousDatabase.");
            const pathParams = {
                "{autonomousDatabaseId}": deleteAutonomousDatabaseRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteAutonomousDatabaseRequest.ifMatch,
                "opc-request-id": deleteAutonomousDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteAutonomousDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes the specified Autonomous VM cluster in an Exadata Cloud@Customer system.
     *
     * @param DeleteAutonomousVmClusterRequest
     * @return DeleteAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     */
    deleteAutonomousVmCluster(deleteAutonomousVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteAutonomousVmCluster.");
            const pathParams = {
                "{autonomousVmClusterId}": deleteAutonomousVmClusterRequest.autonomousVmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteAutonomousVmClusterRequest.ifMatch,
                "opc-request-id": deleteAutonomousVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousVmClusters/{autonomousVmClusterId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteAutonomousVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes a full backup. You cannot delete automatic backups using this API.
     * @param DeleteBackupRequest
     * @return DeleteBackupResponse
     * @throws OciError when an error occurs
     */
    deleteBackup(deleteBackupRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteBackup.");
            const pathParams = {
                "{backupId}": deleteBackupRequest.backupId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteBackupRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/backups/{backupId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteBackupRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes a backup destination in an Exadata Cloud@Customer system.
     *
     * @param DeleteBackupDestinationRequest
     * @return DeleteBackupDestinationResponse
     * @throws OciError when an error occurs
     */
    deleteBackupDestination(deleteBackupDestinationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteBackupDestination.");
            const pathParams = {
                "{backupDestinationId}": deleteBackupDestinationRequest.backupDestinationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteBackupDestinationRequest.ifMatch,
                "opc-request-id": deleteBackupDestinationRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/backupDestinations/{backupDestinationId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteBackupDestinationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes the cloud Exadata infrastructure resource.
     *
     * @param DeleteCloudExadataInfrastructureRequest
     * @return DeleteCloudExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    deleteCloudExadataInfrastructure(deleteCloudExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteCloudExadataInfrastructure.");
            const pathParams = {
                "{cloudExadataInfrastructureId}": deleteCloudExadataInfrastructureRequest.cloudExadataInfrastructureId
            };
            const queryParams = {
                "isDeleteVmClusters": deleteCloudExadataInfrastructureRequest.isDeleteVmClusters
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteCloudExadataInfrastructureRequest.ifMatch,
                "opc-request-id": deleteCloudExadataInfrastructureRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudExadataInfrastructures/{cloudExadataInfrastructureId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteCloudExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes the specified cloud VM cluster.
     *
     * @param DeleteCloudVmClusterRequest
     * @return DeleteCloudVmClusterResponse
     * @throws OciError when an error occurs
     */
    deleteCloudVmCluster(deleteCloudVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteCloudVmCluster.");
            const pathParams = {
                "{cloudVmClusterId}": deleteCloudVmClusterRequest.cloudVmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteCloudVmClusterRequest.ifMatch,
                "opc-request-id": deleteCloudVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters/{cloudVmClusterId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteCloudVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes the specified database node console connection.
     * @param DeleteConsoleConnectionRequest
     * @return DeleteConsoleConnectionResponse
     * @throws OciError when an error occurs
     */
    deleteConsoleConnection(deleteConsoleConnectionRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteConsoleConnection.");
            const pathParams = {
                "{dbNodeId}": deleteConsoleConnectionRequest.dbNodeId,
                "{consoleConnectionId}": deleteConsoleConnectionRequest.consoleConnectionId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteConsoleConnectionRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbNodes/{dbNodeId}/consoleConnections/{consoleConnectionId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteConsoleConnectionRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
       * Deletes the specified database. Applies only to Exadata systems.
  * <p>
  The data in this database is local to the Exadata system and will be lost when the database is deleted. Oracle recommends that you back up any data in the Exadata system prior to deleting it. You can use the `performFinalBackup` parameter to have the Exadata system database backed up before it is deleted.
  *
       * @param DeleteDatabaseRequest
       * @return DeleteDatabaseResponse
       * @throws OciError when an error occurs
       */
    deleteDatabase(deleteDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteDatabase.");
            const pathParams = {
                "{databaseId}": deleteDatabaseRequest.databaseId
            };
            const queryParams = {
                "performFinalBackup": deleteDatabaseRequest.performFinalBackup
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteDatabaseRequest.ifMatch,
                "opc-request-id": deleteDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Delete a database software image
     * @param DeleteDatabaseSoftwareImageRequest
     * @return DeleteDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     */
    deleteDatabaseSoftwareImage(deleteDatabaseSoftwareImageRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteDatabaseSoftwareImage.");
            const pathParams = {
                "{databaseSoftwareImageId}": deleteDatabaseSoftwareImageRequest.databaseSoftwareImageId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteDatabaseSoftwareImageRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databaseSoftwareImages/{databaseSoftwareImageId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteDatabaseSoftwareImageRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
       * Deletes a Database Home. Applies to bare metal DB systems, Exadata Cloud Service, and Exadata Cloud@Customer systems.
  * <p>
  Oracle recommends that you use the `performFinalBackup` parameter to back up any data on a bare metal DB system before you delete a Database Home. On an Exadata Cloud@Customer system or an Exadata Cloud Service system, you can delete a Database Home only when there are no databases in it and therefore you cannot use the `performFinalBackup` parameter to back up data.
  *
       * @param DeleteDbHomeRequest
       * @return DeleteDbHomeResponse
       * @throws OciError when an error occurs
       */
    deleteDbHome(deleteDbHomeRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteDbHome.");
            const pathParams = {
                "{dbHomeId}": deleteDbHomeRequest.dbHomeId
            };
            const queryParams = {
                "performFinalBackup": deleteDbHomeRequest.performFinalBackup
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteDbHomeRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbHomes/{dbHomeId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteDbHomeRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes the Exadata Cloud@Customer infrastructure.
     *
     * @param DeleteExadataInfrastructureRequest
     * @return DeleteExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    deleteExadataInfrastructure(deleteExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteExadataInfrastructure.");
            const pathParams = {
                "{exadataInfrastructureId}": deleteExadataInfrastructureRequest.exadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteExadataInfrastructureRequest.ifMatch,
                "opc-request-id": deleteExadataInfrastructureRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes a key store.
     *
     * @param DeleteKeyStoreRequest
     * @return DeleteKeyStoreResponse
     * @throws OciError when an error occurs
     */
    deleteKeyStore(deleteKeyStoreRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteKeyStore.");
            const pathParams = {
                "{keyStoreId}": deleteKeyStoreRequest.keyStoreId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteKeyStoreRequest.ifMatch,
                "opc-request-id": deleteKeyStoreRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/keyStores/{keyStoreId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteKeyStoreRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes the specified Exadata Cloud@Customer VM cluster.
     *
     * @param DeleteVmClusterRequest
     * @return DeleteVmClusterResponse
     * @throws OciError when an error occurs
     */
    deleteVmCluster(deleteVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteVmCluster.");
            const pathParams = {
                "{vmClusterId}": deleteVmClusterRequest.vmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteVmClusterRequest.ifMatch,
                "opc-request-id": deleteVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/vmClusters/{vmClusterId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Deletes the specified Exadata Cloud@Customer VM cluster network.
     *
     * @param DeleteVmClusterNetworkRequest
     * @return DeleteVmClusterNetworkResponse
     * @throws OciError when an error occurs
     */
    deleteVmClusterNetwork(deleteVmClusterNetworkRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deleteVmClusterNetwork.");
            const pathParams = {
                "{exadataInfrastructureId}": deleteVmClusterNetworkRequest.exadataInfrastructureId,
                "{vmClusterNetworkId}": deleteVmClusterNetworkRequest.vmClusterNetworkId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": deleteVmClusterNetworkRequest.ifMatch,
                "opc-request-id": deleteVmClusterNetworkRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/vmClusterNetworks/{vmClusterNetworkId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deleteVmClusterNetworkRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Asynchronously deregisters this Autonomous Database with Data Safe.
     *
     * @param DeregisterAutonomousDatabaseDataSafeRequest
     * @return DeregisterAutonomousDatabaseDataSafeResponse
     * @throws OciError when an error occurs
     */
    deregisterAutonomousDatabaseDataSafe(deregisterAutonomousDatabaseDataSafeRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#deregisterAutonomousDatabaseDataSafe.");
            const pathParams = {
                "{autonomousDatabaseId}": deregisterAutonomousDatabaseDataSafeRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": deregisterAutonomousDatabaseDataSafeRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/deregisterDataSafe",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(deregisterAutonomousDatabaseDataSafeRequest.deregisterAutonomousDatabaseDataSafeDetails, "DeregisterAutonomousDatabaseDataSafeDetails", models.DeregisterAutonomousDatabaseDataSafeDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, deregisterAutonomousDatabaseDataSafeRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Disables Operations Insights for the Autonomous Database resource.
     *
     * @param DisableAutonomousDatabaseOperationsInsightsRequest
     * @return DisableAutonomousDatabaseOperationsInsightsResponse
     * @throws OciError when an error occurs
     */
    disableAutonomousDatabaseOperationsInsights(disableAutonomousDatabaseOperationsInsightsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#disableAutonomousDatabaseOperationsInsights.");
            const pathParams = {
                "{autonomousDatabaseId}": disableAutonomousDatabaseOperationsInsightsRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": disableAutonomousDatabaseOperationsInsightsRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/disableOperationsInsights",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, disableAutonomousDatabaseOperationsInsightsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Downloads the configuration file for the specified Exadata Cloud@Customer infrastructure.
     *
     * @param DownloadExadataInfrastructureConfigFileRequest
     * @return DownloadExadataInfrastructureConfigFileResponse
     * @throws OciError when an error occurs
     */
    downloadExadataInfrastructureConfigFile(downloadExadataInfrastructureConfigFileRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#downloadExadataInfrastructureConfigFile.");
            const pathParams = {
                "{exadataInfrastructureId}": downloadExadataInfrastructureConfigFileRequest.exadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": downloadExadataInfrastructureConfigFileRequest.opcRequestId,
                "opc-retry-token": downloadExadataInfrastructureConfigFileRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/actions/downloadConfigFile",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, downloadExadataInfrastructureConfigFileRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: response.body,
                    bodyKey: "value",
                    bodyModel: "string",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("content-length"),
                            key: "contentLength",
                            dataType: "number"
                        },
                        {
                            value: response.headers.get("last-modified"),
                            key: "lastModified",
                            dataType: "Date"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Downloads the configuration file for the specified Exadata Cloud@Customer VM cluster network.
     *
     * @param DownloadVmClusterNetworkConfigFileRequest
     * @return DownloadVmClusterNetworkConfigFileResponse
     * @throws OciError when an error occurs
     */
    downloadVmClusterNetworkConfigFile(downloadVmClusterNetworkConfigFileRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#downloadVmClusterNetworkConfigFile.");
            const pathParams = {
                "{exadataInfrastructureId}": downloadVmClusterNetworkConfigFileRequest.exadataInfrastructureId,
                "{vmClusterNetworkId}": downloadVmClusterNetworkConfigFileRequest.vmClusterNetworkId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": downloadVmClusterNetworkConfigFileRequest.opcRequestId,
                "opc-retry-token": downloadVmClusterNetworkConfigFileRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/vmClusterNetworks/{vmClusterNetworkId}/actions/downloadConfigFile",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, downloadVmClusterNetworkConfigFileRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: response.body,
                    bodyKey: "value",
                    bodyModel: "string",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("content-length"),
                            key: "contentLength",
                            dataType: "number"
                        },
                        {
                            value: response.headers.get("last-modified"),
                            key: "lastModified",
                            dataType: "Date"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Enables the specified Autonomous Database with Operations Insights.
     *
     * @param EnableAutonomousDatabaseOperationsInsightsRequest
     * @return EnableAutonomousDatabaseOperationsInsightsResponse
     * @throws OciError when an error occurs
     */
    enableAutonomousDatabaseOperationsInsights(enableAutonomousDatabaseOperationsInsightsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#enableAutonomousDatabaseOperationsInsights.");
            const pathParams = {
                "{autonomousDatabaseId}": enableAutonomousDatabaseOperationsInsightsRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": enableAutonomousDatabaseOperationsInsightsRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/enableOperationsInsights",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, enableAutonomousDatabaseOperationsInsightsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Initiates a failover the specified Autonomous Database to a standby.
     *
     * @param FailOverAutonomousDatabaseRequest
     * @return FailOverAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     */
    failOverAutonomousDatabase(failOverAutonomousDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#failOverAutonomousDatabase.");
            const pathParams = {
                "{autonomousDatabaseId}": failOverAutonomousDatabaseRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": failOverAutonomousDatabaseRequest.ifMatch,
                "opc-retry-token": failOverAutonomousDatabaseRequest.opcRetryToken,
                "opc-request-id": failOverAutonomousDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/failover",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, failOverAutonomousDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
       * Fails over the standby Autonomous Container Database identified by the autonomousContainerDatabaseId parameter to the primary Autonomous Container Database after the existing primary Autonomous Container Database fails or becomes unreachable.
  * <p>
  A failover can result in data loss, depending on the protection mode in effect at the time the primary Autonomous Container Database fails.
  *
       * @param FailoverAutonomousContainerDatabaseDataguardAssociationRequest
       * @return FailoverAutonomousContainerDatabaseDataguardAssociationResponse
       * @throws OciError when an error occurs
       */
    failoverAutonomousContainerDatabaseDataguardAssociation(failoverAutonomousContainerDatabaseDataguardAssociationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#failoverAutonomousContainerDatabaseDataguardAssociation.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": failoverAutonomousContainerDatabaseDataguardAssociationRequest.autonomousContainerDatabaseId,
                "{autonomousContainerDatabaseDataguardAssociationId}": failoverAutonomousContainerDatabaseDataguardAssociationRequest.autonomousContainerDatabaseDataguardAssociationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": failoverAutonomousContainerDatabaseDataguardAssociationRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}/autonomousContainerDatabaseDataguardAssociations/{autonomousContainerDatabaseDataguardAssociationId}/actions/failover",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, failoverAutonomousContainerDatabaseDataguardAssociationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousContainerDatabaseDataguardAssociation",
                    bodyModel: "model.AutonomousContainerDatabaseDataguardAssociation",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
       * Performs a failover to transition the standby database identified by the `databaseId` parameter into the
  * specified Data Guard association's primary role after the existing primary database fails or becomes unreachable.
  * <p>
  A failover might result in data loss depending on the protection mode in effect at the time of the primary
  * database failure.
  *
       * @param FailoverDataGuardAssociationRequest
       * @return FailoverDataGuardAssociationResponse
       * @throws OciError when an error occurs
       */
    failoverDataGuardAssociation(failoverDataGuardAssociationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#failoverDataGuardAssociation.");
            const pathParams = {
                "{databaseId}": failoverDataGuardAssociationRequest.databaseId,
                "{dataGuardAssociationId}": failoverDataGuardAssociationRequest.dataGuardAssociationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": failoverDataGuardAssociationRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}/dataGuardAssociations/{dataGuardAssociationId}/actions/failover",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(failoverDataGuardAssociationRequest.failoverDataGuardAssociationDetails, "FailoverDataGuardAssociationDetails", models.FailoverDataGuardAssociationDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, failoverDataGuardAssociationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dataGuardAssociation",
                    bodyModel: "model.DataGuardAssociation",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * **Deprecated.** To create and download a wallet for an Autonomous Data Warehouse, use the {@link #generateAutonomousDatabaseWallet(GenerateAutonomousDatabaseWalletRequest) generateAutonomousDatabaseWallet} operation.
     *
     * @param GenerateAutonomousDataWarehouseWalletRequest
     * @return GenerateAutonomousDataWarehouseWalletResponse
     * @throws OciError when an error occurs
     */
    generateAutonomousDataWarehouseWallet(generateAutonomousDataWarehouseWalletRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#generateAutonomousDataWarehouseWallet.");
            const pathParams = {
                "{autonomousDataWarehouseId}": generateAutonomousDataWarehouseWalletRequest.autonomousDataWarehouseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": generateAutonomousDataWarehouseWalletRequest.opcRequestId,
                "opc-retry-token": generateAutonomousDataWarehouseWalletRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouses/{autonomousDataWarehouseId}/actions/generateWallet",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(generateAutonomousDataWarehouseWalletRequest.generateAutonomousDataWarehouseWalletDetails, "GenerateAutonomousDataWarehouseWalletDetails", models.GenerateAutonomousDataWarehouseWalletDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, generateAutonomousDataWarehouseWalletRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: response.body,
                    bodyKey: "value",
                    bodyModel: "string",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("content-length"),
                            key: "contentLength",
                            dataType: "number"
                        },
                        {
                            value: response.headers.get("last-modified"),
                            key: "lastModified",
                            dataType: "Date"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates and downloads a wallet for the specified Autonomous Database.
     *
     * @param GenerateAutonomousDatabaseWalletRequest
     * @return GenerateAutonomousDatabaseWalletResponse
     * @throws OciError when an error occurs
     */
    generateAutonomousDatabaseWallet(generateAutonomousDatabaseWalletRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#generateAutonomousDatabaseWallet.");
            const pathParams = {
                "{autonomousDatabaseId}": generateAutonomousDatabaseWalletRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": generateAutonomousDatabaseWalletRequest.opcRequestId,
                "opc-retry-token": generateAutonomousDatabaseWalletRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/generateWallet",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(generateAutonomousDatabaseWalletRequest.generateAutonomousDatabaseWalletDetails, "GenerateAutonomousDatabaseWalletDetails", models.GenerateAutonomousDatabaseWalletDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, generateAutonomousDatabaseWalletRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: response.body,
                    bodyKey: "value",
                    bodyModel: "string",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("content-length"),
                            key: "contentLength",
                            dataType: "number"
                        },
                        {
                            value: response.headers.get("last-modified"),
                            key: "lastModified",
                            dataType: "Date"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Generates a recommended Cloud@Customer VM cluster network configuration.
     *
     * @param GenerateRecommendedVmClusterNetworkRequest
     * @return GenerateRecommendedVmClusterNetworkResponse
     * @throws OciError when an error occurs
     */
    generateRecommendedVmClusterNetwork(generateRecommendedVmClusterNetworkRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#generateRecommendedVmClusterNetwork.");
            const pathParams = {
                "{exadataInfrastructureId}": generateRecommendedVmClusterNetworkRequest.exadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": generateRecommendedVmClusterNetworkRequest.opcRequestId,
                "opc-retry-token": generateRecommendedVmClusterNetworkRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/vmClusterNetworks/actions/generateRecommendedNetwork",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(generateRecommendedVmClusterNetworkRequest.generateRecommendedNetworkDetails, "GenerateRecommendedNetworkDetails", models.GenerateRecommendedNetworkDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, generateRecommendedVmClusterNetworkRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "vmClusterNetworkDetails",
                    bodyModel: "model.VmClusterNetworkDetails",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified Autonomous Container Database.
     * @param GetAutonomousContainerDatabaseRequest
     * @return GetAutonomousContainerDatabaseResponse
     * @throws OciError when an error occurs
     */
    getAutonomousContainerDatabase(getAutonomousContainerDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousContainerDatabase.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": getAutonomousContainerDatabaseRequest.autonomousContainerDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousContainerDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousContainerDatabase",
                    bodyModel: "model.AutonomousContainerDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets an Autonomous Container Database enabled with Autonomous Data Guard associated with the specified Autonomous Container Database.
     *
     * @param GetAutonomousContainerDatabaseDataguardAssociationRequest
     * @return GetAutonomousContainerDatabaseDataguardAssociationResponse
     * @throws OciError when an error occurs
     */
    getAutonomousContainerDatabaseDataguardAssociation(getAutonomousContainerDatabaseDataguardAssociationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousContainerDatabaseDataguardAssociation.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": getAutonomousContainerDatabaseDataguardAssociationRequest.autonomousContainerDatabaseId,
                "{autonomousContainerDatabaseDataguardAssociationId}": getAutonomousContainerDatabaseDataguardAssociationRequest.autonomousContainerDatabaseDataguardAssociationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}/autonomousContainerDatabaseDataguardAssociations/{autonomousContainerDatabaseDataguardAssociationId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousContainerDatabaseDataguardAssociationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousContainerDatabaseDataguardAssociation",
                    bodyModel: "model.AutonomousContainerDatabaseDataguardAssociation",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * **Deprecated.** To get the details of an Autonomous Data Warehouse, use the {@link #getAutonomousDatabase(GetAutonomousDatabaseRequest) getAutonomousDatabase} operation.
     *
     * @param GetAutonomousDataWarehouseRequest
     * @return GetAutonomousDataWarehouseResponse
     * @throws OciError when an error occurs
     */
    getAutonomousDataWarehouse(getAutonomousDataWarehouseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousDataWarehouse.");
            const pathParams = {
                "{autonomousDataWarehouseId}": getAutonomousDataWarehouseRequest.autonomousDataWarehouseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouses/{autonomousDataWarehouseId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousDataWarehouseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDataWarehouse",
                    bodyModel: "model.AutonomousDataWarehouse",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * **Deprecated.** To get information about a specified Autonomous Data Warehouse backup, use the {@link #getAutonomousDatabaseBackup(GetAutonomousDatabaseBackupRequest) getAutonomousDatabaseBackup} operation.
     *
     * @param GetAutonomousDataWarehouseBackupRequest
     * @return GetAutonomousDataWarehouseBackupResponse
     * @throws OciError when an error occurs
     */
    getAutonomousDataWarehouseBackup(getAutonomousDataWarehouseBackupRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousDataWarehouseBackup.");
            const pathParams = {
                "{autonomousDataWarehouseBackupId}": getAutonomousDataWarehouseBackupRequest.autonomousDataWarehouseBackupId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouseBackups/{autonomousDataWarehouseBackupId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousDataWarehouseBackupRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDataWarehouseBackup",
                    bodyModel: "model.AutonomousDataWarehouseBackup",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the details of the specified Autonomous Database.
     *
     * @param GetAutonomousDatabaseRequest
     * @return GetAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     */
    getAutonomousDatabase(getAutonomousDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousDatabase.");
            const pathParams = {
                "{autonomousDatabaseId}": getAutonomousDatabaseRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getAutonomousDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified Autonomous Database backup.
     * @param GetAutonomousDatabaseBackupRequest
     * @return GetAutonomousDatabaseBackupResponse
     * @throws OciError when an error occurs
     */
    getAutonomousDatabaseBackup(getAutonomousDatabaseBackupRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousDatabaseBackup.");
            const pathParams = {
                "{autonomousDatabaseBackupId}": getAutonomousDatabaseBackupRequest.autonomousDatabaseBackupId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getAutonomousDatabaseBackupRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabaseBackups/{autonomousDatabaseBackupId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousDatabaseBackupRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabaseBackup",
                    bodyModel: "model.AutonomousDatabaseBackup",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets an Autonomous Data Guard-enabled database associated with the specified Autonomous Database.
     *
     * @param GetAutonomousDatabaseDataguardAssociationRequest
     * @return GetAutonomousDatabaseDataguardAssociationResponse
     * @throws OciError when an error occurs
     */
    getAutonomousDatabaseDataguardAssociation(getAutonomousDatabaseDataguardAssociationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousDatabaseDataguardAssociation.");
            const pathParams = {
                "{autonomousDatabaseId}": getAutonomousDatabaseDataguardAssociationRequest.autonomousDatabaseId,
                "{autonomousDatabaseDataguardAssociationId}": getAutonomousDatabaseDataguardAssociationRequest.autonomousDatabaseDataguardAssociationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getAutonomousDatabaseDataguardAssociationRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/autonomousDatabaseDataguardAssociations/{autonomousDatabaseDataguardAssociationId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousDatabaseDataguardAssociationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabaseDataguardAssociation",
                    bodyModel: "model.AutonomousDatabaseDataguardAssociation",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the Autonomous Database regional wallet details.
     *
     * @param GetAutonomousDatabaseRegionalWalletRequest
     * @return GetAutonomousDatabaseRegionalWalletResponse
     * @throws OciError when an error occurs
     */
    getAutonomousDatabaseRegionalWallet(getAutonomousDatabaseRegionalWalletRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousDatabaseRegionalWallet.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getAutonomousDatabaseRegionalWalletRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/wallet",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousDatabaseRegionalWalletRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabaseWallet",
                    bodyModel: "model.AutonomousDatabaseWallet",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the wallet details for the specified Autonomous Database.
     *
     * @param GetAutonomousDatabaseWalletRequest
     * @return GetAutonomousDatabaseWalletResponse
     * @throws OciError when an error occurs
     */
    getAutonomousDatabaseWallet(getAutonomousDatabaseWalletRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousDatabaseWallet.");
            const pathParams = {
                "{autonomousDatabaseId}": getAutonomousDatabaseWalletRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getAutonomousDatabaseWalletRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/wallet",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousDatabaseWalletRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabaseWallet",
                    bodyModel: "model.AutonomousDatabaseWallet",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified Autonomous Exadata Infrastructure resource.
     * @param GetAutonomousExadataInfrastructureRequest
     * @return GetAutonomousExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    getAutonomousExadataInfrastructure(getAutonomousExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousExadataInfrastructure.");
            const pathParams = {
                "{autonomousExadataInfrastructureId}": getAutonomousExadataInfrastructureRequest.autonomousExadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousExadataInfrastructures/{autonomousExadataInfrastructureId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousExadataInfrastructure",
                    bodyModel: "model.AutonomousExadataInfrastructure",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about a specific autonomous patch.
     * @param GetAutonomousPatchRequest
     * @return GetAutonomousPatchResponse
     * @throws OciError when an error occurs
     */
    getAutonomousPatch(getAutonomousPatchRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousPatch.");
            const pathParams = {
                "{autonomousPatchId}": getAutonomousPatchRequest.autonomousPatchId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousPatches/{autonomousPatchId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousPatchRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousPatch",
                    bodyModel: "model.AutonomousPatch",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified Autonomous VM cluster for an Exadata Cloud@Customer system.
     * @param GetAutonomousVmClusterRequest
     * @return GetAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     */
    getAutonomousVmCluster(getAutonomousVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getAutonomousVmCluster.");
            const pathParams = {
                "{autonomousVmClusterId}": getAutonomousVmClusterRequest.autonomousVmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getAutonomousVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousVmClusters/{autonomousVmClusterId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getAutonomousVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousVmCluster",
                    bodyModel: "model.AutonomousVmCluster",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified backup.
     * @param GetBackupRequest
     * @return GetBackupResponse
     * @throws OciError when an error occurs
     */
    getBackup(getBackupRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getBackup.");
            const pathParams = {
                "{backupId}": getBackupRequest.backupId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/backups/{backupId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getBackupRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "backup",
                    bodyModel: "model.Backup",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified backup destination in an Exadata Cloud@Customer system.
     *
     * @param GetBackupDestinationRequest
     * @return GetBackupDestinationResponse
     * @throws OciError when an error occurs
     */
    getBackupDestination(getBackupDestinationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getBackupDestination.");
            const pathParams = {
                "{backupDestinationId}": getBackupDestinationRequest.backupDestinationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getBackupDestinationRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/backupDestinations/{backupDestinationId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getBackupDestinationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "backupDestination",
                    bodyModel: "model.BackupDestination",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified cloud Exadata infrastructure resource.
     * @param GetCloudExadataInfrastructureRequest
     * @return GetCloudExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    getCloudExadataInfrastructure(getCloudExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getCloudExadataInfrastructure.");
            const pathParams = {
                "{cloudExadataInfrastructureId}": getCloudExadataInfrastructureRequest.cloudExadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getCloudExadataInfrastructureRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudExadataInfrastructures/{cloudExadataInfrastructureId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getCloudExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "cloudExadataInfrastructure",
                    bodyModel: "model.CloudExadataInfrastructure",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified cloud VM cluster.
     * @param GetCloudVmClusterRequest
     * @return GetCloudVmClusterResponse
     * @throws OciError when an error occurs
     */
    getCloudVmCluster(getCloudVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getCloudVmCluster.");
            const pathParams = {
                "{cloudVmClusterId}": getCloudVmClusterRequest.cloudVmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getCloudVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters/{cloudVmClusterId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getCloudVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "cloudVmCluster",
                    bodyModel: "model.CloudVmCluster",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the IORM configuration for the specified cloud VM cluster.
     * If you have not specified an IORM configuration, the default configuration is returned.
     *
     * @param GetCloudVmClusterIormConfigRequest
     * @return GetCloudVmClusterIormConfigResponse
     * @throws OciError when an error occurs
     */
    getCloudVmClusterIormConfig(getCloudVmClusterIormConfigRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getCloudVmClusterIormConfig.");
            const pathParams = {
                "{cloudVmClusterId}": getCloudVmClusterIormConfigRequest.cloudVmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getCloudVmClusterIormConfigRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters/{cloudVmClusterId}/CloudVmClusterIormConfig",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getCloudVmClusterIormConfigRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "exadataIormConfig",
                    bodyModel: "model.ExadataIormConfig",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about a specified maintenance update package.
     *
     * @param GetCloudVmClusterUpdateRequest
     * @return GetCloudVmClusterUpdateResponse
     * @throws OciError when an error occurs
     */
    getCloudVmClusterUpdate(getCloudVmClusterUpdateRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getCloudVmClusterUpdate.");
            const pathParams = {
                "{cloudVmClusterId}": getCloudVmClusterUpdateRequest.cloudVmClusterId,
                "{updateId}": getCloudVmClusterUpdateRequest.updateId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getCloudVmClusterUpdateRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters/{cloudVmClusterId}/updates/{updateId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getCloudVmClusterUpdateRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "update",
                    bodyModel: "model.Update",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the maintenance update history details for the specified update history entry.
     *
     * @param GetCloudVmClusterUpdateHistoryEntryRequest
     * @return GetCloudVmClusterUpdateHistoryEntryResponse
     * @throws OciError when an error occurs
     */
    getCloudVmClusterUpdateHistoryEntry(getCloudVmClusterUpdateHistoryEntryRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getCloudVmClusterUpdateHistoryEntry.");
            const pathParams = {
                "{cloudVmClusterId}": getCloudVmClusterUpdateHistoryEntryRequest.cloudVmClusterId,
                "{updateHistoryEntryId}": getCloudVmClusterUpdateHistoryEntryRequest.updateHistoryEntryId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getCloudVmClusterUpdateHistoryEntryRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters/{cloudVmClusterId}/updateHistoryEntries/{updateHistoryEntryId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getCloudVmClusterUpdateHistoryEntryRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "updateHistoryEntry",
                    bodyModel: "model.UpdateHistoryEntry",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the specified database node console connection's information.
     * @param GetConsoleConnectionRequest
     * @return GetConsoleConnectionResponse
     * @throws OciError when an error occurs
     */
    getConsoleConnection(getConsoleConnectionRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getConsoleConnection.");
            const pathParams = {
                "{dbNodeId}": getConsoleConnectionRequest.dbNodeId,
                "{consoleConnectionId}": getConsoleConnectionRequest.consoleConnectionId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbNodes/{dbNodeId}/consoleConnections/{consoleConnectionId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getConsoleConnectionRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "consoleConnection",
                    bodyModel: "model.ConsoleConnection",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the specified Data Guard association's configuration information.
     *
     * @param GetDataGuardAssociationRequest
     * @return GetDataGuardAssociationResponse
     * @throws OciError when an error occurs
     */
    getDataGuardAssociation(getDataGuardAssociationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDataGuardAssociation.");
            const pathParams = {
                "{databaseId}": getDataGuardAssociationRequest.databaseId,
                "{dataGuardAssociationId}": getDataGuardAssociationRequest.dataGuardAssociationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}/dataGuardAssociations/{dataGuardAssociationId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDataGuardAssociationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dataGuardAssociation",
                    bodyModel: "model.DataGuardAssociation",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified database.
     * @param GetDatabaseRequest
     * @return GetDatabaseResponse
     * @throws OciError when an error occurs
     */
    getDatabase(getDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDatabase.");
            const pathParams = {
                "{databaseId}": getDatabaseRequest.databaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "database",
                    bodyModel: "model.Database",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified database software image.
     * @param GetDatabaseSoftwareImageRequest
     * @return GetDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     */
    getDatabaseSoftwareImage(getDatabaseSoftwareImageRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDatabaseSoftwareImage.");
            const pathParams = {
                "{databaseSoftwareImageId}": getDatabaseSoftwareImageRequest.databaseSoftwareImageId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databaseSoftwareImages/{databaseSoftwareImageId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDatabaseSoftwareImageRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "databaseSoftwareImage",
                    bodyModel: "model.DatabaseSoftwareImage",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * gets the upgrade history for a specified database.
     *
     * @param GetDatabaseUpgradeHistoryEntryRequest
     * @return GetDatabaseUpgradeHistoryEntryResponse
     * @throws OciError when an error occurs
     */
    getDatabaseUpgradeHistoryEntry(getDatabaseUpgradeHistoryEntryRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDatabaseUpgradeHistoryEntry.");
            const pathParams = {
                "{databaseId}": getDatabaseUpgradeHistoryEntryRequest.databaseId,
                "{upgradeHistoryEntryId}": getDatabaseUpgradeHistoryEntryRequest.upgradeHistoryEntryId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getDatabaseUpgradeHistoryEntryRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}/upgradeHistoryEntries/{upgradeHistoryEntryId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDatabaseUpgradeHistoryEntryRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "databaseUpgradeHistoryEntry",
                    bodyModel: "model.DatabaseUpgradeHistoryEntry",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified Database Home.
     * @param GetDbHomeRequest
     * @return GetDbHomeResponse
     * @throws OciError when an error occurs
     */
    getDbHome(getDbHomeRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDbHome.");
            const pathParams = {
                "{dbHomeId}": getDbHomeRequest.dbHomeId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbHomes/{dbHomeId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDbHomeRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dbHome",
                    bodyModel: "model.DbHome",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about a specified patch package.
     *
     * @param GetDbHomePatchRequest
     * @return GetDbHomePatchResponse
     * @throws OciError when an error occurs
     */
    getDbHomePatch(getDbHomePatchRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDbHomePatch.");
            const pathParams = {
                "{dbHomeId}": getDbHomePatchRequest.dbHomeId,
                "{patchId}": getDbHomePatchRequest.patchId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbHomes/{dbHomeId}/patches/{patchId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDbHomePatchRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "patch",
                    bodyModel: "model.Patch",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the patch history details for the specified patchHistoryEntryId
     *
     * @param GetDbHomePatchHistoryEntryRequest
     * @return GetDbHomePatchHistoryEntryResponse
     * @throws OciError when an error occurs
     */
    getDbHomePatchHistoryEntry(getDbHomePatchHistoryEntryRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDbHomePatchHistoryEntry.");
            const pathParams = {
                "{dbHomeId}": getDbHomePatchHistoryEntryRequest.dbHomeId,
                "{patchHistoryEntryId}": getDbHomePatchHistoryEntryRequest.patchHistoryEntryId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbHomes/{dbHomeId}/patchHistoryEntries/{patchHistoryEntryId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDbHomePatchHistoryEntryRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "patchHistoryEntry",
                    bodyModel: "model.PatchHistoryEntry",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified database node.
     * @param GetDbNodeRequest
     * @return GetDbNodeResponse
     * @throws OciError when an error occurs
     */
    getDbNode(getDbNodeRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDbNode.");
            const pathParams = {
                "{dbNodeId}": getDbNodeRequest.dbNodeId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbNodes/{dbNodeId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDbNodeRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dbNode",
                    bodyModel: "model.DbNode",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified DB system.
     * @param GetDbSystemRequest
     * @return GetDbSystemResponse
     * @throws OciError when an error occurs
     */
    getDbSystem(getDbSystemRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDbSystem.");
            const pathParams = {
                "{dbSystemId}": getDbSystemRequest.dbSystemId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDbSystemRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dbSystem",
                    bodyModel: "model.DbSystem",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information the specified patch.
     *
     * @param GetDbSystemPatchRequest
     * @return GetDbSystemPatchResponse
     * @throws OciError when an error occurs
     */
    getDbSystemPatch(getDbSystemPatchRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDbSystemPatch.");
            const pathParams = {
                "{dbSystemId}": getDbSystemPatchRequest.dbSystemId,
                "{patchId}": getDbSystemPatchRequest.patchId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}/patches/{patchId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDbSystemPatchRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "patch",
                    bodyModel: "model.Patch",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the details of the specified patch operation on the specified DB system.
     *
     * @param GetDbSystemPatchHistoryEntryRequest
     * @return GetDbSystemPatchHistoryEntryResponse
     * @throws OciError when an error occurs
     */
    getDbSystemPatchHistoryEntry(getDbSystemPatchHistoryEntryRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getDbSystemPatchHistoryEntry.");
            const pathParams = {
                "{dbSystemId}": getDbSystemPatchHistoryEntryRequest.dbSystemId,
                "{patchHistoryEntryId}": getDbSystemPatchHistoryEntryRequest.patchHistoryEntryId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}/patchHistoryEntries/{patchHistoryEntryId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getDbSystemPatchHistoryEntryRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "patchHistoryEntry",
                    bodyModel: "model.PatchHistoryEntry",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified Exadata Cloud@Customer infrastructure.
     * @param GetExadataInfrastructureRequest
     * @return GetExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    getExadataInfrastructure(getExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getExadataInfrastructure.");
            const pathParams = {
                "{exadataInfrastructureId}": getExadataInfrastructureRequest.exadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getExadataInfrastructureRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "exadataInfrastructure",
                    bodyModel: "model.ExadataInfrastructure",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets details of the available and consumed OCPUs for the specified Autonomous Exadata Infrastructure resource.
     *
     * @param GetExadataInfrastructureOcpusRequest
     * @return GetExadataInfrastructureOcpusResponse
     * @throws OciError when an error occurs
     */
    getExadataInfrastructureOcpus(getExadataInfrastructureOcpusRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getExadataInfrastructureOcpus.");
            const pathParams = {
                "{autonomousExadataInfrastructureId}": getExadataInfrastructureOcpusRequest.autonomousExadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getExadataInfrastructureOcpusRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousExadataInfrastructures/{autonomousExadataInfrastructureId}/ocpus",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getExadataInfrastructureOcpusRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "oCPUs",
                    bodyModel: "model.OCPUs",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the IORM configuration settings for the specified cloud Exadata system.
     * All Exadata service instances have default IORM settings.
     *
     * @param GetExadataIormConfigRequest
     * @return GetExadataIormConfigResponse
     * @throws OciError when an error occurs
     */
    getExadataIormConfig(getExadataIormConfigRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getExadataIormConfig.");
            const pathParams = {
                "{dbSystemId}": getExadataIormConfigRequest.dbSystemId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getExadataIormConfigRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}/ExadataIormConfig",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getExadataIormConfigRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "exadataIormConfig",
                    bodyModel: "model.ExadataIormConfig",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified external backup job.
     * <p>
     **Note:** This API is used by an Oracle Cloud Infrastructure Python script that is packaged with the Oracle Cloud Infrastructure CLI. Oracle recommends that you use the script instead using the API directly. See [Migrating an On-Premises Database to Oracle Cloud Infrastructure by Creating a Backup in the Cloud](https://docs.cloud.oracle.com/Content/Database/Tasks/mig-onprembackup.htm) for more information.
     *
     * @param GetExternalBackupJobRequest
     * @return GetExternalBackupJobResponse
     * @throws OciError when an error occurs
     */
    getExternalBackupJob(getExternalBackupJobRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getExternalBackupJob.");
            const pathParams = {
                "{backupId}": getExternalBackupJobRequest.backupId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/externalBackupJobs/{backupId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getExternalBackupJobRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "externalBackupJob",
                    bodyModel: "model.ExternalBackupJob",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified key store.
     *
     * @param GetKeyStoreRequest
     * @return GetKeyStoreResponse
     * @throws OciError when an error occurs
     */
    getKeyStore(getKeyStoreRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getKeyStore.");
            const pathParams = {
                "{keyStoreId}": getKeyStoreRequest.keyStoreId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getKeyStoreRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/keyStores/{keyStoreId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getKeyStoreRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "keyStore",
                    bodyModel: "model.KeyStore",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified maintenance run.
     * @param GetMaintenanceRunRequest
     * @return GetMaintenanceRunResponse
     * @throws OciError when an error occurs
     */
    getMaintenanceRun(getMaintenanceRunRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getMaintenanceRun.");
            const pathParams = {
                "{maintenanceRunId}": getMaintenanceRunRequest.maintenanceRunId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/maintenanceRuns/{maintenanceRunId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getMaintenanceRunRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "maintenanceRun",
                    bodyModel: "model.MaintenanceRun",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified Exadata Cloud@Customer VM cluster.
     * @param GetVmClusterRequest
     * @return GetVmClusterResponse
     * @throws OciError when an error occurs
     */
    getVmCluster(getVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getVmCluster.");
            const pathParams = {
                "{vmClusterId}": getVmClusterRequest.vmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/vmClusters/{vmClusterId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "vmCluster",
                    bodyModel: "model.VmCluster",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about the specified Exadata Cloud@Customer VM cluster network.
     * @param GetVmClusterNetworkRequest
     * @return GetVmClusterNetworkResponse
     * @throws OciError when an error occurs
     */
    getVmClusterNetwork(getVmClusterNetworkRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getVmClusterNetwork.");
            const pathParams = {
                "{exadataInfrastructureId}": getVmClusterNetworkRequest.exadataInfrastructureId,
                "{vmClusterNetworkId}": getVmClusterNetworkRequest.vmClusterNetworkId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": getVmClusterNetworkRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/vmClusterNetworks/{vmClusterNetworkId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getVmClusterNetworkRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "vmClusterNetwork",
                    bodyModel: "model.VmClusterNetwork",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets information about a specified patch package.
     *
     * @param GetVmClusterPatchRequest
     * @return GetVmClusterPatchResponse
     * @throws OciError when an error occurs
     */
    getVmClusterPatch(getVmClusterPatchRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getVmClusterPatch.");
            const pathParams = {
                "{vmClusterId}": getVmClusterPatchRequest.vmClusterId,
                "{patchId}": getVmClusterPatchRequest.patchId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/vmClusters/{vmClusterId}/patches/{patchId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getVmClusterPatchRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "patch",
                    bodyModel: "model.Patch",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets the patch history details for the specified patch history entry.
     *
     * @param GetVmClusterPatchHistoryEntryRequest
     * @return GetVmClusterPatchHistoryEntryResponse
     * @throws OciError when an error occurs
     */
    getVmClusterPatchHistoryEntry(getVmClusterPatchHistoryEntryRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#getVmClusterPatchHistoryEntry.");
            const pathParams = {
                "{vmClusterId}": getVmClusterPatchHistoryEntryRequest.vmClusterId,
                "{patchHistoryEntryId}": getVmClusterPatchHistoryEntryRequest.patchHistoryEntryId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/vmClusters/{vmClusterId}/patchHistoryEntries/{patchHistoryEntryId}",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, getVmClusterPatchHistoryEntryRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "patchHistoryEntry",
                    bodyModel: "model.PatchHistoryEntry",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new Autonomous Exadata Infrastructure in the specified compartment and availability domain.
     *
     * @param LaunchAutonomousExadataInfrastructureRequest
     * @return LaunchAutonomousExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    launchAutonomousExadataInfrastructure(launchAutonomousExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#launchAutonomousExadataInfrastructure.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": launchAutonomousExadataInfrastructureRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousExadataInfrastructures",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(launchAutonomousExadataInfrastructureRequest.launchAutonomousExadataInfrastructureDetails, "LaunchAutonomousExadataInfrastructureDetails", models.LaunchAutonomousExadataInfrastructureDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, launchAutonomousExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousExadataInfrastructure",
                    bodyModel: "model.AutonomousExadataInfrastructure",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
       * Creates a new DB system in the specified compartment and availability domain. The Oracle
  * Database edition that you specify applies to all the databases on that DB system. The selected edition cannot be changed.
  * <p>
  An initial database is created on the DB system based on the request parameters you provide and some default
  * options. For detailed information about default options, see the following:
  * <p>
  - [Bare metal and virtual machine DB system default options](https://docs.cloud.oracle.com/Content/Database/Tasks/creatingDBsystem.htm#DefaultOptionsfortheInitialDatabase)
  * - [Exadata DB system default options](https://docs.cloud.oracle.com/Content/Database/Tasks/exacreatingDBsystem.htm#DefaultOptionsfortheInitialDatabase)
  *
       * @param LaunchDbSystemRequest
       * @return LaunchDbSystemResponse
       * @throws OciError when an error occurs
       */
    launchDbSystem(launchDbSystemRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#launchDbSystem.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-retry-token": launchDbSystemRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(launchDbSystemRequest.launchDbSystemDetails, "LaunchDbSystemBase", models.LaunchDbSystemBase.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, launchDbSystemRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dbSystem",
                    bodyModel: "model.DbSystem",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Gets a list of the Autonomous Container Databases with Autonomous Data Guard enabled associated with the specified Autonomous Container Database.
     *
     * @param ListAutonomousContainerDatabaseDataguardAssociationsRequest
     * @return ListAutonomousContainerDatabaseDataguardAssociationsResponse
     * @throws OciError when an error occurs
     */
    listAutonomousContainerDatabaseDataguardAssociations(listAutonomousContainerDatabaseDataguardAssociationsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousContainerDatabaseDataguardAssociations.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": listAutonomousContainerDatabaseDataguardAssociationsRequest.autonomousContainerDatabaseId
            };
            const queryParams = {
                "limit": listAutonomousContainerDatabaseDataguardAssociationsRequest.limit,
                "page": listAutonomousContainerDatabaseDataguardAssociationsRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}/autonomousContainerDatabaseDataguardAssociations",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousContainerDatabaseDataguardAssociationsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousContainerDatabaseDataguardAssociation[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseDataguardAssociation objects
     * contained in responses from the listAutonomousContainerDatabaseDataguardAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousContainerDatabaseDataguardAssociations(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousContainerDatabaseDataguardAssociations(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousContainerDatabaseDataguardAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousContainerDatabaseDataguardAssociationsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousContainerDatabaseDataguardAssociations(req));
    }
    /**
     * Gets a list of the Autonomous Container Databases in the specified compartment.
     *
     * @param ListAutonomousContainerDatabasesRequest
     * @return ListAutonomousContainerDatabasesResponse
     * @throws OciError when an error occurs
     */
    listAutonomousContainerDatabases(listAutonomousContainerDatabasesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousContainerDatabases.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listAutonomousContainerDatabasesRequest.compartmentId,
                "autonomousExadataInfrastructureId": listAutonomousContainerDatabasesRequest.autonomousExadataInfrastructureId,
                "autonomousVmClusterId": listAutonomousContainerDatabasesRequest.autonomousVmClusterId,
                "infrastructureType": listAutonomousContainerDatabasesRequest.infrastructureType,
                "limit": listAutonomousContainerDatabasesRequest.limit,
                "page": listAutonomousContainerDatabasesRequest.page,
                "sortBy": listAutonomousContainerDatabasesRequest.sortBy,
                "sortOrder": listAutonomousContainerDatabasesRequest.sortOrder,
                "lifecycleState": listAutonomousContainerDatabasesRequest.lifecycleState,
                "availabilityDomain": listAutonomousContainerDatabasesRequest.availabilityDomain,
                "displayName": listAutonomousContainerDatabasesRequest.displayName,
                "serviceLevelAgreementType": listAutonomousContainerDatabasesRequest.serviceLevelAgreementType
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousContainerDatabasesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousContainerDatabaseSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseSummary objects
     * contained in responses from the listAutonomousContainerDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousContainerDatabases(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousContainerDatabases(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousContainerDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousContainerDatabasesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousContainerDatabases(req));
    }
    /**
     * **Deprecated.** To get a list of Autonomous Data Warehouse backups, use the {@link #listAutonomousDatabaseBackups(ListAutonomousDatabaseBackupsRequest) listAutonomousDatabaseBackups} operation.
     *
     * @param ListAutonomousDataWarehouseBackupsRequest
     * @return ListAutonomousDataWarehouseBackupsResponse
     * @throws OciError when an error occurs
     */
    listAutonomousDataWarehouseBackups(listAutonomousDataWarehouseBackupsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousDataWarehouseBackups.");
            const pathParams = {};
            const queryParams = {
                "autonomousDataWarehouseId": listAutonomousDataWarehouseBackupsRequest.autonomousDataWarehouseId,
                "compartmentId": listAutonomousDataWarehouseBackupsRequest.compartmentId,
                "limit": listAutonomousDataWarehouseBackupsRequest.limit,
                "page": listAutonomousDataWarehouseBackupsRequest.page,
                "sortBy": listAutonomousDataWarehouseBackupsRequest.sortBy,
                "sortOrder": listAutonomousDataWarehouseBackupsRequest.sortOrder,
                "lifecycleState": listAutonomousDataWarehouseBackupsRequest.lifecycleState,
                "displayName": listAutonomousDataWarehouseBackupsRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouseBackups",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousDataWarehouseBackupsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousDataWarehouseBackupSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDataWarehouseBackupSummary objects
     * contained in responses from the listAutonomousDataWarehouseBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDataWarehouseBackups(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousDataWarehouseBackups(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDataWarehouseBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDataWarehouseBackupsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousDataWarehouseBackups(req));
    }
    /**
     * **Deprecated.** To get a list of Autonomous Data Warehouses, use the {@link #listAutonomousDatabases(ListAutonomousDatabasesRequest) listAutonomousDatabases} operation and specify `DW` as the workload type.
     *
     * @param ListAutonomousDataWarehousesRequest
     * @return ListAutonomousDataWarehousesResponse
     * @throws OciError when an error occurs
     */
    listAutonomousDataWarehouses(listAutonomousDataWarehousesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousDataWarehouses.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listAutonomousDataWarehousesRequest.compartmentId,
                "limit": listAutonomousDataWarehousesRequest.limit,
                "page": listAutonomousDataWarehousesRequest.page,
                "sortBy": listAutonomousDataWarehousesRequest.sortBy,
                "sortOrder": listAutonomousDataWarehousesRequest.sortOrder,
                "lifecycleState": listAutonomousDataWarehousesRequest.lifecycleState,
                "displayName": listAutonomousDataWarehousesRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouses",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousDataWarehousesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousDataWarehouseSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDataWarehouseSummary objects
     * contained in responses from the listAutonomousDataWarehouses operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDataWarehouses(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousDataWarehouses(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDataWarehouses operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDataWarehousesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousDataWarehouses(req));
    }
    /**
     * Gets a list of Autonomous Database backups based on either the `autonomousDatabaseId` or `compartmentId` specified as a query parameter.
     *
     * @param ListAutonomousDatabaseBackupsRequest
     * @return ListAutonomousDatabaseBackupsResponse
     * @throws OciError when an error occurs
     */
    listAutonomousDatabaseBackups(listAutonomousDatabaseBackupsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousDatabaseBackups.");
            const pathParams = {};
            const queryParams = {
                "autonomousDatabaseId": listAutonomousDatabaseBackupsRequest.autonomousDatabaseId,
                "compartmentId": listAutonomousDatabaseBackupsRequest.compartmentId,
                "limit": listAutonomousDatabaseBackupsRequest.limit,
                "page": listAutonomousDatabaseBackupsRequest.page,
                "sortBy": listAutonomousDatabaseBackupsRequest.sortBy,
                "sortOrder": listAutonomousDatabaseBackupsRequest.sortOrder,
                "lifecycleState": listAutonomousDatabaseBackupsRequest.lifecycleState,
                "displayName": listAutonomousDatabaseBackupsRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listAutonomousDatabaseBackupsRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabaseBackups",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousDatabaseBackupsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousDatabaseBackupSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseBackupSummary objects
     * contained in responses from the listAutonomousDatabaseBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseBackups(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousDatabaseBackups(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabaseBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseBackupsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousDatabaseBackups(req));
    }
    /**
     * Lists the Autonomous Database clones for the specified Autonomous Database.
     *
     * @param ListAutonomousDatabaseClonesRequest
     * @return ListAutonomousDatabaseClonesResponse
     * @throws OciError when an error occurs
     */
    listAutonomousDatabaseClones(listAutonomousDatabaseClonesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousDatabaseClones.");
            const pathParams = {
                "{autonomousDatabaseId}": listAutonomousDatabaseClonesRequest.autonomousDatabaseId
            };
            const queryParams = {
                "compartmentId": listAutonomousDatabaseClonesRequest.compartmentId,
                "limit": listAutonomousDatabaseClonesRequest.limit,
                "page": listAutonomousDatabaseClonesRequest.page,
                "sortOrder": listAutonomousDatabaseClonesRequest.sortOrder,
                "displayName": listAutonomousDatabaseClonesRequest.displayName,
                "lifecycleState": listAutonomousDatabaseClonesRequest.lifecycleState,
                "sortBy": listAutonomousDatabaseClonesRequest.sortBy,
                "cloneType": listAutonomousDatabaseClonesRequest.cloneType
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listAutonomousDatabaseClonesRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/clones",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousDatabaseClonesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousDatabaseSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseSummary objects
     * contained in responses from the listAutonomousDatabaseClones operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseClones(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousDatabaseClones(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabaseClones operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseClonesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousDatabaseClones(req));
    }
    /**
     * Gets a list of the Autonomous Data Guard-enabled databases associated with the specified Autonomous Database.
     *
     * @param ListAutonomousDatabaseDataguardAssociationsRequest
     * @return ListAutonomousDatabaseDataguardAssociationsResponse
     * @throws OciError when an error occurs
     */
    listAutonomousDatabaseDataguardAssociations(listAutonomousDatabaseDataguardAssociationsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousDatabaseDataguardAssociations.");
            const pathParams = {
                "{autonomousDatabaseId}": listAutonomousDatabaseDataguardAssociationsRequest.autonomousDatabaseId
            };
            const queryParams = {
                "limit": listAutonomousDatabaseDataguardAssociationsRequest.limit,
                "page": listAutonomousDatabaseDataguardAssociationsRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/autonomousDatabaseDataguardAssociations",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousDatabaseDataguardAssociationsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousDatabaseDataguardAssociation[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseDataguardAssociation objects
     * contained in responses from the listAutonomousDatabaseDataguardAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseDataguardAssociations(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousDatabaseDataguardAssociations(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabaseDataguardAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseDataguardAssociationsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousDatabaseDataguardAssociations(req));
    }
    /**
     * Gets a list of Autonomous Databases based on the query parameters specified.
     *
     * @param ListAutonomousDatabasesRequest
     * @return ListAutonomousDatabasesResponse
     * @throws OciError when an error occurs
     */
    listAutonomousDatabases(listAutonomousDatabasesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousDatabases.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listAutonomousDatabasesRequest.compartmentId,
                "autonomousContainerDatabaseId": listAutonomousDatabasesRequest.autonomousContainerDatabaseId,
                "limit": listAutonomousDatabasesRequest.limit,
                "page": listAutonomousDatabasesRequest.page,
                "sortBy": listAutonomousDatabasesRequest.sortBy,
                "sortOrder": listAutonomousDatabasesRequest.sortOrder,
                "infrastructureType": listAutonomousDatabasesRequest.infrastructureType,
                "lifecycleState": listAutonomousDatabasesRequest.lifecycleState,
                "dbWorkload": listAutonomousDatabasesRequest.dbWorkload,
                "dbVersion": listAutonomousDatabasesRequest.dbVersion,
                "isFreeTier": listAutonomousDatabasesRequest.isFreeTier,
                "displayName": listAutonomousDatabasesRequest.displayName,
                "isRefreshableClone": listAutonomousDatabasesRequest.isRefreshableClone,
                "isDataGuardEnabled": listAutonomousDatabasesRequest.isDataGuardEnabled
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listAutonomousDatabasesRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousDatabasesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousDatabaseSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseSummary objects
     * contained in responses from the listAutonomousDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabases(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousDatabases(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabasesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousDatabases(req));
    }
    /**
     * Gets a list of supported Autonomous Database versions. Note that preview version software is only available for
     * databases with [shared Exadata infrastructure](https://docs.cloud.oracle.com/Content/Database/Concepts/adboverview.htm#AEI).
     *
     * @param ListAutonomousDbPreviewVersionsRequest
     * @return ListAutonomousDbPreviewVersionsResponse
     * @throws OciError when an error occurs
     */
    listAutonomousDbPreviewVersions(listAutonomousDbPreviewVersionsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousDbPreviewVersions.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listAutonomousDbPreviewVersionsRequest.compartmentId,
                "limit": listAutonomousDbPreviewVersionsRequest.limit,
                "page": listAutonomousDbPreviewVersionsRequest.page,
                "sortBy": listAutonomousDbPreviewVersionsRequest.sortBy,
                "sortOrder": listAutonomousDbPreviewVersionsRequest.sortOrder
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listAutonomousDbPreviewVersionsRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDbPreviewVersions",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousDbPreviewVersionsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousDbPreviewVersionSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDbPreviewVersionSummary objects
     * contained in responses from the listAutonomousDbPreviewVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDbPreviewVersions(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousDbPreviewVersions(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDbPreviewVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDbPreviewVersionsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousDbPreviewVersions(req));
    }
    /**
     * Gets a list of supported Autonomous Database versions.
     * @param ListAutonomousDbVersionsRequest
     * @return ListAutonomousDbVersionsResponse
     * @throws OciError when an error occurs
     */
    listAutonomousDbVersions(listAutonomousDbVersionsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousDbVersions.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listAutonomousDbVersionsRequest.compartmentId,
                "limit": listAutonomousDbVersionsRequest.limit,
                "page": listAutonomousDbVersionsRequest.page,
                "dbWorkload": listAutonomousDbVersionsRequest.dbWorkload,
                "sortOrder": listAutonomousDbVersionsRequest.sortOrder
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listAutonomousDbVersionsRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDbVersions",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousDbVersionsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousDbVersionSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDbVersionSummary objects
     * contained in responses from the listAutonomousDbVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDbVersions(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousDbVersions(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDbVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDbVersionsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousDbVersions(req));
    }
    /**
     * Gets a list of the shapes that can be used to launch a new Autonomous Exadata Infrastructure resource. The shape determines resources to allocate (CPU cores, memory and storage).
     * @param ListAutonomousExadataInfrastructureShapesRequest
     * @return ListAutonomousExadataInfrastructureShapesResponse
     * @throws OciError when an error occurs
     */
    listAutonomousExadataInfrastructureShapes(listAutonomousExadataInfrastructureShapesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousExadataInfrastructureShapes.");
            const pathParams = {};
            const queryParams = {
                "availabilityDomain": listAutonomousExadataInfrastructureShapesRequest.availabilityDomain,
                "compartmentId": listAutonomousExadataInfrastructureShapesRequest.compartmentId,
                "limit": listAutonomousExadataInfrastructureShapesRequest.limit,
                "page": listAutonomousExadataInfrastructureShapesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listAutonomousExadataInfrastructureShapesRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousExadataInfrastructureShapes",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousExadataInfrastructureShapesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousExadataInfrastructureShapeSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousExadataInfrastructureShapeSummary objects
     * contained in responses from the listAutonomousExadataInfrastructureShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousExadataInfrastructureShapes(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousExadataInfrastructureShapes(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousExadataInfrastructureShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousExadataInfrastructureShapesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousExadataInfrastructureShapes(req));
    }
    /**
     * Gets a list of the Autonomous Exadata Infrastructures in the specified compartment.
     *
     * @param ListAutonomousExadataInfrastructuresRequest
     * @return ListAutonomousExadataInfrastructuresResponse
     * @throws OciError when an error occurs
     */
    listAutonomousExadataInfrastructures(listAutonomousExadataInfrastructuresRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousExadataInfrastructures.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listAutonomousExadataInfrastructuresRequest.compartmentId,
                "limit": listAutonomousExadataInfrastructuresRequest.limit,
                "page": listAutonomousExadataInfrastructuresRequest.page,
                "sortBy": listAutonomousExadataInfrastructuresRequest.sortBy,
                "sortOrder": listAutonomousExadataInfrastructuresRequest.sortOrder,
                "lifecycleState": listAutonomousExadataInfrastructuresRequest.lifecycleState,
                "availabilityDomain": listAutonomousExadataInfrastructuresRequest.availabilityDomain,
                "displayName": listAutonomousExadataInfrastructuresRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousExadataInfrastructures",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousExadataInfrastructuresRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousExadataInfrastructureSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousExadataInfrastructureSummary objects
     * contained in responses from the listAutonomousExadataInfrastructures operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousExadataInfrastructures(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousExadataInfrastructures(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousExadataInfrastructures operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousExadataInfrastructuresResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousExadataInfrastructures(req));
    }
    /**
     * Gets a list of Exadata Cloud@Customer Autonomous VM clusters in the specified compartment.
     *
     * @param ListAutonomousVmClustersRequest
     * @return ListAutonomousVmClustersResponse
     * @throws OciError when an error occurs
     */
    listAutonomousVmClusters(listAutonomousVmClustersRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listAutonomousVmClusters.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listAutonomousVmClustersRequest.compartmentId,
                "exadataInfrastructureId": listAutonomousVmClustersRequest.exadataInfrastructureId,
                "limit": listAutonomousVmClustersRequest.limit,
                "page": listAutonomousVmClustersRequest.page,
                "sortBy": listAutonomousVmClustersRequest.sortBy,
                "sortOrder": listAutonomousVmClustersRequest.sortOrder,
                "lifecycleState": listAutonomousVmClustersRequest.lifecycleState,
                "displayName": listAutonomousVmClustersRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listAutonomousVmClustersRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousVmClusters",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listAutonomousVmClustersRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousVmClusterSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousVmClusterSummary objects
     * contained in responses from the listAutonomousVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousVmClusters(request) {
        return oci_common_1.paginateRecords(request, req => this.listAutonomousVmClusters(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousVmClustersResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listAutonomousVmClusters(req));
    }
    /**
     * Gets a list of backup destinations in the specified compartment.
     *
     * @param ListBackupDestinationRequest
     * @return ListBackupDestinationResponse
     * @throws OciError when an error occurs
     */
    listBackupDestination(listBackupDestinationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listBackupDestination.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listBackupDestinationRequest.compartmentId,
                "limit": listBackupDestinationRequest.limit,
                "page": listBackupDestinationRequest.page,
                "type": listBackupDestinationRequest.type
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listBackupDestinationRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/backupDestinations",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listBackupDestinationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "BackupDestinationSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.BackupDestinationSummary objects
     * contained in responses from the listBackupDestination operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBackupDestination(request) {
        return oci_common_1.paginateRecords(request, req => this.listBackupDestination(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBackupDestination operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBackupDestinationResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listBackupDestination(req));
    }
    /**
     * Gets a list of backups based on the `databaseId` or `compartmentId` specified. Either one of these query parameters must be provided.
     *
     * @param ListBackupsRequest
     * @return ListBackupsResponse
     * @throws OciError when an error occurs
     */
    listBackups(listBackupsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listBackups.");
            const pathParams = {};
            const queryParams = {
                "databaseId": listBackupsRequest.databaseId,
                "compartmentId": listBackupsRequest.compartmentId,
                "limit": listBackupsRequest.limit,
                "page": listBackupsRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/backups",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listBackupsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "BackupSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.BackupSummary objects
     * contained in responses from the listBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBackups(request) {
        return oci_common_1.paginateRecords(request, req => this.listBackups(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBackupsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listBackups(req));
    }
    /**
     * Gets a list of the cloud Exadata infrastructure in the specified compartment.
     *
     * @param ListCloudExadataInfrastructuresRequest
     * @return ListCloudExadataInfrastructuresResponse
     * @throws OciError when an error occurs
     */
    listCloudExadataInfrastructures(listCloudExadataInfrastructuresRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listCloudExadataInfrastructures.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listCloudExadataInfrastructuresRequest.compartmentId,
                "limit": listCloudExadataInfrastructuresRequest.limit,
                "page": listCloudExadataInfrastructuresRequest.page,
                "sortBy": listCloudExadataInfrastructuresRequest.sortBy,
                "sortOrder": listCloudExadataInfrastructuresRequest.sortOrder,
                "lifecycleState": listCloudExadataInfrastructuresRequest.lifecycleState,
                "displayName": listCloudExadataInfrastructuresRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listCloudExadataInfrastructuresRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudExadataInfrastructures",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listCloudExadataInfrastructuresRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "CloudExadataInfrastructureSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.CloudExadataInfrastructureSummary objects
     * contained in responses from the listCloudExadataInfrastructures operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudExadataInfrastructures(request) {
        return oci_common_1.paginateRecords(request, req => this.listCloudExadataInfrastructures(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCloudExadataInfrastructures operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudExadataInfrastructuresResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listCloudExadataInfrastructures(req));
    }
    /**
     * Gets the history of the maintenance update actions performed on the specified cloud VM cluster.
     *
     * @param ListCloudVmClusterUpdateHistoryEntriesRequest
     * @return ListCloudVmClusterUpdateHistoryEntriesResponse
     * @throws OciError when an error occurs
     */
    listCloudVmClusterUpdateHistoryEntries(listCloudVmClusterUpdateHistoryEntriesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listCloudVmClusterUpdateHistoryEntries.");
            const pathParams = {
                "{cloudVmClusterId}": listCloudVmClusterUpdateHistoryEntriesRequest.cloudVmClusterId
            };
            const queryParams = {
                "updateType": listCloudVmClusterUpdateHistoryEntriesRequest.updateType,
                "limit": listCloudVmClusterUpdateHistoryEntriesRequest.limit,
                "page": listCloudVmClusterUpdateHistoryEntriesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listCloudVmClusterUpdateHistoryEntriesRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters/{cloudVmClusterId}/updateHistoryEntries",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listCloudVmClusterUpdateHistoryEntriesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "UpdateHistoryEntrySummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.UpdateHistoryEntrySummary objects
     * contained in responses from the listCloudVmClusterUpdateHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClusterUpdateHistoryEntries(request) {
        return oci_common_1.paginateRecords(request, req => this.listCloudVmClusterUpdateHistoryEntries(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCloudVmClusterUpdateHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClusterUpdateHistoryEntriesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listCloudVmClusterUpdateHistoryEntries(req));
    }
    /**
     * Lists the maintenance updates that can be applied to the requested cloud VM cluster.
     *
     * @param ListCloudVmClusterUpdatesRequest
     * @return ListCloudVmClusterUpdatesResponse
     * @throws OciError when an error occurs
     */
    listCloudVmClusterUpdates(listCloudVmClusterUpdatesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listCloudVmClusterUpdates.");
            const pathParams = {
                "{cloudVmClusterId}": listCloudVmClusterUpdatesRequest.cloudVmClusterId
            };
            const queryParams = {
                "updateType": listCloudVmClusterUpdatesRequest.updateType,
                "limit": listCloudVmClusterUpdatesRequest.limit,
                "page": listCloudVmClusterUpdatesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listCloudVmClusterUpdatesRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters/{cloudVmClusterId}/updates",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listCloudVmClusterUpdatesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "UpdateSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.UpdateSummary objects
     * contained in responses from the listCloudVmClusterUpdates operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClusterUpdates(request) {
        return oci_common_1.paginateRecords(request, req => this.listCloudVmClusterUpdates(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCloudVmClusterUpdates operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClusterUpdatesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listCloudVmClusterUpdates(req));
    }
    /**
     * Gets a list of the cloud VM clusters in the specified compartment.
     *
     * @param ListCloudVmClustersRequest
     * @return ListCloudVmClustersResponse
     * @throws OciError when an error occurs
     */
    listCloudVmClusters(listCloudVmClustersRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listCloudVmClusters.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listCloudVmClustersRequest.compartmentId,
                "cloudExadataInfrastructureId": listCloudVmClustersRequest.cloudExadataInfrastructureId,
                "limit": listCloudVmClustersRequest.limit,
                "page": listCloudVmClustersRequest.page,
                "sortBy": listCloudVmClustersRequest.sortBy,
                "sortOrder": listCloudVmClustersRequest.sortOrder,
                "lifecycleState": listCloudVmClustersRequest.lifecycleState,
                "displayName": listCloudVmClustersRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listCloudVmClustersRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listCloudVmClustersRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "CloudVmClusterSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.CloudVmClusterSummary objects
     * contained in responses from the listCloudVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClusters(request) {
        return oci_common_1.paginateRecords(request, req => this.listCloudVmClusters(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCloudVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClustersResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listCloudVmClusters(req));
    }
    /**
     * Lists the console connections for the specified database node.
     *
     * @param ListConsoleConnectionsRequest
     * @return ListConsoleConnectionsResponse
     * @throws OciError when an error occurs
     */
    listConsoleConnections(listConsoleConnectionsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listConsoleConnections.");
            const pathParams = {
                "{dbNodeId}": listConsoleConnectionsRequest.dbNodeId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbNodes/{dbNodeId}/consoleConnections",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listConsoleConnectionsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "ConsoleConnectionSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Lists the patches applicable to the requested container database.
     *
     * @param ListContainerDatabasePatchesRequest
     * @return ListContainerDatabasePatchesResponse
     * @throws OciError when an error occurs
     */
    listContainerDatabasePatches(listContainerDatabasePatchesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listContainerDatabasePatches.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": listContainerDatabasePatchesRequest.autonomousContainerDatabaseId
            };
            const queryParams = {
                "limit": listContainerDatabasePatchesRequest.limit,
                "page": listContainerDatabasePatchesRequest.page,
                "compartmentId": listContainerDatabasePatchesRequest.compartmentId
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}/patches",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listContainerDatabasePatchesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "AutonomousPatchSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousPatchSummary objects
     * contained in responses from the listContainerDatabasePatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllContainerDatabasePatches(request) {
        return oci_common_1.paginateRecords(request, req => this.listContainerDatabasePatches(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listContainerDatabasePatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllContainerDatabasePatchesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listContainerDatabasePatches(req));
    }
    /**
     * Lists all Data Guard associations for the specified database.
     *
     * @param ListDataGuardAssociationsRequest
     * @return ListDataGuardAssociationsResponse
     * @throws OciError when an error occurs
     */
    listDataGuardAssociations(listDataGuardAssociationsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDataGuardAssociations.");
            const pathParams = {
                "{databaseId}": listDataGuardAssociationsRequest.databaseId
            };
            const queryParams = {
                "limit": listDataGuardAssociationsRequest.limit,
                "page": listDataGuardAssociationsRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}/dataGuardAssociations",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDataGuardAssociationsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "DataGuardAssociationSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.DataGuardAssociationSummary objects
     * contained in responses from the listDataGuardAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDataGuardAssociations(request) {
        return oci_common_1.paginateRecords(request, req => this.listDataGuardAssociations(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDataGuardAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDataGuardAssociationsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDataGuardAssociations(req));
    }
    /**
     * Gets a list of the database software images in the specified compartment.
     *
     * @param ListDatabaseSoftwareImagesRequest
     * @return ListDatabaseSoftwareImagesResponse
     * @throws OciError when an error occurs
     */
    listDatabaseSoftwareImages(listDatabaseSoftwareImagesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDatabaseSoftwareImages.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listDatabaseSoftwareImagesRequest.compartmentId,
                "limit": listDatabaseSoftwareImagesRequest.limit,
                "page": listDatabaseSoftwareImagesRequest.page,
                "sortBy": listDatabaseSoftwareImagesRequest.sortBy,
                "sortOrder": listDatabaseSoftwareImagesRequest.sortOrder,
                "lifecycleState": listDatabaseSoftwareImagesRequest.lifecycleState,
                "displayName": listDatabaseSoftwareImagesRequest.displayName,
                "imageType": listDatabaseSoftwareImagesRequest.imageType,
                "imageShapeFamily": listDatabaseSoftwareImagesRequest.imageShapeFamily,
                "isUpgradeSupported": listDatabaseSoftwareImagesRequest.isUpgradeSupported
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databaseSoftwareImages",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDatabaseSoftwareImagesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "DatabaseSoftwareImageSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.DatabaseSoftwareImageSummary objects
     * contained in responses from the listDatabaseSoftwareImages operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabaseSoftwareImages(request) {
        return oci_common_1.paginateRecords(request, req => this.listDatabaseSoftwareImages(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDatabaseSoftwareImages operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabaseSoftwareImagesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDatabaseSoftwareImages(req));
    }
    /**
     * gets the upgrade history for a specified database.
     *
     * @param ListDatabaseUpgradeHistoryEntriesRequest
     * @return ListDatabaseUpgradeHistoryEntriesResponse
     * @throws OciError when an error occurs
     */
    listDatabaseUpgradeHistoryEntries(listDatabaseUpgradeHistoryEntriesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDatabaseUpgradeHistoryEntries.");
            const pathParams = {
                "{databaseId}": listDatabaseUpgradeHistoryEntriesRequest.databaseId
            };
            const queryParams = {
                "upgradeAction": listDatabaseUpgradeHistoryEntriesRequest.upgradeAction,
                "lifecycleState": listDatabaseUpgradeHistoryEntriesRequest.lifecycleState,
                "sortBy": listDatabaseUpgradeHistoryEntriesRequest.sortBy,
                "sortOrder": listDatabaseUpgradeHistoryEntriesRequest.sortOrder,
                "limit": listDatabaseUpgradeHistoryEntriesRequest.limit,
                "page": listDatabaseUpgradeHistoryEntriesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listDatabaseUpgradeHistoryEntriesRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}/upgradeHistoryEntries",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDatabaseUpgradeHistoryEntriesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "DatabaseUpgradeHistoryEntrySummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.DatabaseUpgradeHistoryEntrySummary objects
     * contained in responses from the listDatabaseUpgradeHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabaseUpgradeHistoryEntries(request) {
        return oci_common_1.paginateRecords(request, req => this.listDatabaseUpgradeHistoryEntries(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDatabaseUpgradeHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabaseUpgradeHistoryEntriesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDatabaseUpgradeHistoryEntries(req));
    }
    /**
     * Gets a list of the databases in the specified Database Home.
     *
     * @param ListDatabasesRequest
     * @return ListDatabasesResponse
     * @throws OciError when an error occurs
     */
    listDatabases(listDatabasesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDatabases.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listDatabasesRequest.compartmentId,
                "dbHomeId": listDatabasesRequest.dbHomeId,
                "systemId": listDatabasesRequest.systemId,
                "limit": listDatabasesRequest.limit,
                "page": listDatabasesRequest.page,
                "sortBy": listDatabasesRequest.sortBy,
                "sortOrder": listDatabasesRequest.sortOrder,
                "lifecycleState": listDatabasesRequest.lifecycleState,
                "dbName": listDatabasesRequest.dbName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDatabasesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "DatabaseSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.DatabaseSummary objects
     * contained in responses from the listDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabases(request) {
        return oci_common_1.paginateRecords(request, req => this.listDatabases(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabasesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDatabases(req));
    }
    /**
     * Lists the history of patch operations on the specified Database Home.
     *
     * @param ListDbHomePatchHistoryEntriesRequest
     * @return ListDbHomePatchHistoryEntriesResponse
     * @throws OciError when an error occurs
     */
    listDbHomePatchHistoryEntries(listDbHomePatchHistoryEntriesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDbHomePatchHistoryEntries.");
            const pathParams = {
                "{dbHomeId}": listDbHomePatchHistoryEntriesRequest.dbHomeId
            };
            const queryParams = {
                "limit": listDbHomePatchHistoryEntriesRequest.limit,
                "page": listDbHomePatchHistoryEntriesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbHomes/{dbHomeId}/patchHistoryEntries",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDbHomePatchHistoryEntriesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "PatchHistoryEntrySummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.PatchHistoryEntrySummary objects
     * contained in responses from the listDbHomePatchHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomePatchHistoryEntries(request) {
        return oci_common_1.paginateRecords(request, req => this.listDbHomePatchHistoryEntries(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbHomePatchHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomePatchHistoryEntriesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDbHomePatchHistoryEntries(req));
    }
    /**
     * Lists patches applicable to the requested Database Home.
     *
     * @param ListDbHomePatchesRequest
     * @return ListDbHomePatchesResponse
     * @throws OciError when an error occurs
     */
    listDbHomePatches(listDbHomePatchesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDbHomePatches.");
            const pathParams = {
                "{dbHomeId}": listDbHomePatchesRequest.dbHomeId
            };
            const queryParams = {
                "limit": listDbHomePatchesRequest.limit,
                "page": listDbHomePatchesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbHomes/{dbHomeId}/patches",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDbHomePatchesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "PatchSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listDbHomePatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomePatches(request) {
        return oci_common_1.paginateRecords(request, req => this.listDbHomePatches(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbHomePatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomePatchesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDbHomePatches(req));
    }
    /**
     * Lists the Database Homes in the specified DB system and compartment. A Database Home is a directory where Oracle Database software is installed.
     *
     * @param ListDbHomesRequest
     * @return ListDbHomesResponse
     * @throws OciError when an error occurs
     */
    listDbHomes(listDbHomesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDbHomes.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listDbHomesRequest.compartmentId,
                "dbSystemId": listDbHomesRequest.dbSystemId,
                "vmClusterId": listDbHomesRequest.vmClusterId,
                "backupId": listDbHomesRequest.backupId,
                "dbVersion": listDbHomesRequest.dbVersion,
                "limit": listDbHomesRequest.limit,
                "page": listDbHomesRequest.page,
                "sortBy": listDbHomesRequest.sortBy,
                "sortOrder": listDbHomesRequest.sortOrder,
                "lifecycleState": listDbHomesRequest.lifecycleState,
                "displayName": listDbHomesRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbHomes",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDbHomesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "DbHomeSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.DbHomeSummary objects
     * contained in responses from the listDbHomes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomes(request) {
        return oci_common_1.paginateRecords(request, req => this.listDbHomes(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbHomes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDbHomes(req));
    }
    /**
     * Lists the database nodes in the specified DB system and compartment. A database node is a server running database software.
     *
     * @param ListDbNodesRequest
     * @return ListDbNodesResponse
     * @throws OciError when an error occurs
     */
    listDbNodes(listDbNodesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDbNodes.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listDbNodesRequest.compartmentId,
                "dbSystemId": listDbNodesRequest.dbSystemId,
                "vmClusterId": listDbNodesRequest.vmClusterId,
                "limit": listDbNodesRequest.limit,
                "page": listDbNodesRequest.page,
                "sortBy": listDbNodesRequest.sortBy,
                "sortOrder": listDbNodesRequest.sortOrder,
                "lifecycleState": listDbNodesRequest.lifecycleState
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbNodes",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDbNodesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "DbNodeSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.DbNodeSummary objects
     * contained in responses from the listDbNodes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbNodes(request) {
        return oci_common_1.paginateRecords(request, req => this.listDbNodes(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbNodes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbNodesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDbNodes(req));
    }
    /**
     * Gets the history of the patch actions performed on the specified DB system.
     *
     * @param ListDbSystemPatchHistoryEntriesRequest
     * @return ListDbSystemPatchHistoryEntriesResponse
     * @throws OciError when an error occurs
     */
    listDbSystemPatchHistoryEntries(listDbSystemPatchHistoryEntriesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDbSystemPatchHistoryEntries.");
            const pathParams = {
                "{dbSystemId}": listDbSystemPatchHistoryEntriesRequest.dbSystemId
            };
            const queryParams = {
                "limit": listDbSystemPatchHistoryEntriesRequest.limit,
                "page": listDbSystemPatchHistoryEntriesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}/patchHistoryEntries",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDbSystemPatchHistoryEntriesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "PatchHistoryEntrySummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.PatchHistoryEntrySummary objects
     * contained in responses from the listDbSystemPatchHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemPatchHistoryEntries(request) {
        return oci_common_1.paginateRecords(request, req => this.listDbSystemPatchHistoryEntries(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemPatchHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemPatchHistoryEntriesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDbSystemPatchHistoryEntries(req));
    }
    /**
     * Lists the patches applicable to the specified DB system.
     *
     * @param ListDbSystemPatchesRequest
     * @return ListDbSystemPatchesResponse
     * @throws OciError when an error occurs
     */
    listDbSystemPatches(listDbSystemPatchesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDbSystemPatches.");
            const pathParams = {
                "{dbSystemId}": listDbSystemPatchesRequest.dbSystemId
            };
            const queryParams = {
                "limit": listDbSystemPatchesRequest.limit,
                "page": listDbSystemPatchesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}/patches",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDbSystemPatchesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "PatchSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listDbSystemPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemPatches(request) {
        return oci_common_1.paginateRecords(request, req => this.listDbSystemPatches(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemPatchesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDbSystemPatches(req));
    }
    /**
     * Gets a list of the shapes that can be used to launch a new DB system. The shape determines resources to allocate to the DB system - CPU cores and memory for VM shapes; CPU cores, memory and storage for non-VM (or bare metal) shapes.
     * @param ListDbSystemShapesRequest
     * @return ListDbSystemShapesResponse
     * @throws OciError when an error occurs
     */
    listDbSystemShapes(listDbSystemShapesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDbSystemShapes.");
            const pathParams = {};
            const queryParams = {
                "availabilityDomain": listDbSystemShapesRequest.availabilityDomain,
                "compartmentId": listDbSystemShapesRequest.compartmentId,
                "limit": listDbSystemShapesRequest.limit,
                "page": listDbSystemShapesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystemShapes",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDbSystemShapesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "DbSystemShapeSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.DbSystemShapeSummary objects
     * contained in responses from the listDbSystemShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemShapes(request) {
        return oci_common_1.paginateRecords(request, req => this.listDbSystemShapes(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemShapesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDbSystemShapes(req));
    }
    /**
     * Lists the DB systems in the specified compartment. You can specify a `backupId` to list only the DB systems that support creating a database using this backup in this compartment.
     *
     * @param ListDbSystemsRequest
     * @return ListDbSystemsResponse
     * @throws OciError when an error occurs
     */
    listDbSystems(listDbSystemsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDbSystems.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listDbSystemsRequest.compartmentId,
                "limit": listDbSystemsRequest.limit,
                "page": listDbSystemsRequest.page,
                "backupId": listDbSystemsRequest.backupId,
                "sortBy": listDbSystemsRequest.sortBy,
                "sortOrder": listDbSystemsRequest.sortOrder,
                "lifecycleState": listDbSystemsRequest.lifecycleState,
                "availabilityDomain": listDbSystemsRequest.availabilityDomain,
                "displayName": listDbSystemsRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDbSystemsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "DbSystemSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.DbSystemSummary objects
     * contained in responses from the listDbSystems operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystems(request) {
        return oci_common_1.paginateRecords(request, req => this.listDbSystems(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbSystems operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDbSystems(req));
    }
    /**
     * Gets a list of supported Oracle Database versions.
     * @param ListDbVersionsRequest
     * @return ListDbVersionsResponse
     * @throws OciError when an error occurs
     */
    listDbVersions(listDbVersionsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listDbVersions.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listDbVersionsRequest.compartmentId,
                "limit": listDbVersionsRequest.limit,
                "page": listDbVersionsRequest.page,
                "dbSystemShape": listDbVersionsRequest.dbSystemShape,
                "dbSystemId": listDbVersionsRequest.dbSystemId,
                "storageManagement": listDbVersionsRequest.storageManagement,
                "isUpgradeSupported": listDbVersionsRequest.isUpgradeSupported
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbVersions",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listDbVersionsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "DbVersionSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.DbVersionSummary objects
     * contained in responses from the listDbVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbVersions(request) {
        return oci_common_1.paginateRecords(request, req => this.listDbVersions(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbVersionsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listDbVersions(req));
    }
    /**
     * Gets a list of the Exadata Cloud@Customer infrastructure resources in the specified compartment.
     *
     * @param ListExadataInfrastructuresRequest
     * @return ListExadataInfrastructuresResponse
     * @throws OciError when an error occurs
     */
    listExadataInfrastructures(listExadataInfrastructuresRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listExadataInfrastructures.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listExadataInfrastructuresRequest.compartmentId,
                "limit": listExadataInfrastructuresRequest.limit,
                "page": listExadataInfrastructuresRequest.page,
                "sortBy": listExadataInfrastructuresRequest.sortBy,
                "sortOrder": listExadataInfrastructuresRequest.sortOrder,
                "lifecycleState": listExadataInfrastructuresRequest.lifecycleState,
                "displayName": listExadataInfrastructuresRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listExadataInfrastructuresRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listExadataInfrastructuresRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "ExadataInfrastructureSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.ExadataInfrastructureSummary objects
     * contained in responses from the listExadataInfrastructures operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExadataInfrastructures(request) {
        return oci_common_1.paginateRecords(request, req => this.listExadataInfrastructures(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listExadataInfrastructures operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExadataInfrastructuresResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listExadataInfrastructures(req));
    }
    /**
     * Gets a list of supported GI versions for the Exadata Cloud@Customer VM cluster.
     * @param ListGiVersionsRequest
     * @return ListGiVersionsResponse
     * @throws OciError when an error occurs
     */
    listGiVersions(listGiVersionsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listGiVersions.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listGiVersionsRequest.compartmentId,
                "limit": listGiVersionsRequest.limit,
                "page": listGiVersionsRequest.page,
                "sortOrder": listGiVersionsRequest.sortOrder,
                "shape": listGiVersionsRequest.shape
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/giVersions",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listGiVersionsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "GiVersionSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.GiVersionSummary objects
     * contained in responses from the listGiVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllGiVersions(request) {
        return oci_common_1.paginateRecords(request, req => this.listGiVersions(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listGiVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllGiVersionsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listGiVersions(req));
    }
    /**
     * Gets a list of key stores in the specified compartment.
     *
     * @param ListKeyStoresRequest
     * @return ListKeyStoresResponse
     * @throws OciError when an error occurs
     */
    listKeyStores(listKeyStoresRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listKeyStores.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listKeyStoresRequest.compartmentId,
                "limit": listKeyStoresRequest.limit,
                "page": listKeyStoresRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listKeyStoresRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/keyStores",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listKeyStoresRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "KeyStoreSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.KeyStoreSummary objects
     * contained in responses from the listKeyStores operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllKeyStores(request) {
        return oci_common_1.paginateRecords(request, req => this.listKeyStores(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listKeyStores operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllKeyStoresResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listKeyStores(req));
    }
    /**
     * Gets a list of the maintenance runs in the specified compartment.
     *
     * @param ListMaintenanceRunsRequest
     * @return ListMaintenanceRunsResponse
     * @throws OciError when an error occurs
     */
    listMaintenanceRuns(listMaintenanceRunsRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listMaintenanceRuns.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listMaintenanceRunsRequest.compartmentId,
                "targetResourceId": listMaintenanceRunsRequest.targetResourceId,
                "targetResourceType": listMaintenanceRunsRequest.targetResourceType,
                "maintenanceType": listMaintenanceRunsRequest.maintenanceType,
                "limit": listMaintenanceRunsRequest.limit,
                "page": listMaintenanceRunsRequest.page,
                "sortBy": listMaintenanceRunsRequest.sortBy,
                "sortOrder": listMaintenanceRunsRequest.sortOrder,
                "lifecycleState": listMaintenanceRunsRequest.lifecycleState,
                "availabilityDomain": listMaintenanceRunsRequest.availabilityDomain
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/maintenanceRuns",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listMaintenanceRunsRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "MaintenanceRunSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.MaintenanceRunSummary objects
     * contained in responses from the listMaintenanceRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMaintenanceRuns(request) {
        return oci_common_1.paginateRecords(request, req => this.listMaintenanceRuns(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listMaintenanceRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMaintenanceRunsResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listMaintenanceRuns(req));
    }
    /**
     * Gets a list of the Exadata Cloud@Customer VM cluster networks in the specified compartment.
     *
     * @param ListVmClusterNetworksRequest
     * @return ListVmClusterNetworksResponse
     * @throws OciError when an error occurs
     */
    listVmClusterNetworks(listVmClusterNetworksRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listVmClusterNetworks.");
            const pathParams = {
                "{exadataInfrastructureId}": listVmClusterNetworksRequest.exadataInfrastructureId
            };
            const queryParams = {
                "compartmentId": listVmClusterNetworksRequest.compartmentId,
                "limit": listVmClusterNetworksRequest.limit,
                "page": listVmClusterNetworksRequest.page,
                "sortBy": listVmClusterNetworksRequest.sortBy,
                "sortOrder": listVmClusterNetworksRequest.sortOrder,
                "lifecycleState": listVmClusterNetworksRequest.lifecycleState,
                "displayName": listVmClusterNetworksRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listVmClusterNetworksRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/vmClusterNetworks",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listVmClusterNetworksRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "VmClusterNetworkSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.VmClusterNetworkSummary objects
     * contained in responses from the listVmClusterNetworks operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterNetworks(request) {
        return oci_common_1.paginateRecords(request, req => this.listVmClusterNetworks(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterNetworks operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterNetworksResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listVmClusterNetworks(req));
    }
    /**
     * Gets the history of the patch actions performed on the specified VM cluster in an Exadata Cloud@Customer system.
     *
     * @param ListVmClusterPatchHistoryEntriesRequest
     * @return ListVmClusterPatchHistoryEntriesResponse
     * @throws OciError when an error occurs
     */
    listVmClusterPatchHistoryEntries(listVmClusterPatchHistoryEntriesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listVmClusterPatchHistoryEntries.");
            const pathParams = {
                "{vmClusterId}": listVmClusterPatchHistoryEntriesRequest.vmClusterId
            };
            const queryParams = {
                "limit": listVmClusterPatchHistoryEntriesRequest.limit,
                "page": listVmClusterPatchHistoryEntriesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/vmClusters/{vmClusterId}/patchHistoryEntries",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listVmClusterPatchHistoryEntriesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "PatchHistoryEntrySummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.PatchHistoryEntrySummary objects
     * contained in responses from the listVmClusterPatchHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterPatchHistoryEntries(request) {
        return oci_common_1.paginateRecords(request, req => this.listVmClusterPatchHistoryEntries(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterPatchHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterPatchHistoryEntriesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listVmClusterPatchHistoryEntries(req));
    }
    /**
     * Lists the patches applicable to the specified VM cluster in an Exadata Cloud@Customer system.
     *
     * @param ListVmClusterPatchesRequest
     * @return ListVmClusterPatchesResponse
     * @throws OciError when an error occurs
     */
    listVmClusterPatches(listVmClusterPatchesRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listVmClusterPatches.");
            const pathParams = {
                "{vmClusterId}": listVmClusterPatchesRequest.vmClusterId
            };
            const queryParams = {
                "limit": listVmClusterPatchesRequest.limit,
                "page": listVmClusterPatchesRequest.page
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/vmClusters/{vmClusterId}/patches",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listVmClusterPatchesRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "PatchSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listVmClusterPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterPatches(request) {
        return oci_common_1.paginateRecords(request, req => this.listVmClusterPatches(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterPatchesResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listVmClusterPatches(req));
    }
    /**
     * Gets a list of the Exadata Cloud@Customer VM clusters in the specified compartment.
     *
     * @param ListVmClustersRequest
     * @return ListVmClustersResponse
     * @throws OciError when an error occurs
     */
    listVmClusters(listVmClustersRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#listVmClusters.");
            const pathParams = {};
            const queryParams = {
                "compartmentId": listVmClustersRequest.compartmentId,
                "exadataInfrastructureId": listVmClustersRequest.exadataInfrastructureId,
                "limit": listVmClustersRequest.limit,
                "page": listVmClustersRequest.page,
                "sortBy": listVmClustersRequest.sortBy,
                "sortOrder": listVmClustersRequest.sortOrder,
                "lifecycleState": listVmClustersRequest.lifecycleState,
                "displayName": listVmClustersRequest.displayName
            };
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": listVmClustersRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/vmClusters",
                method: "GET",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, listVmClustersRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "items",
                    bodyModel: "VmClusterSummary[]",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-next-page"),
                            key: "opcNextPage",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new async iterator which will iterate over the models.VmClusterSummary objects
     * contained in responses from the listVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusters(request) {
        return oci_common_1.paginateRecords(request, req => this.listVmClusters(req));
    }
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClustersResponses(request) {
        return oci_common_1.paginateResponses(request, req => this.listVmClusters(req));
    }
    /**
     * Migrates the Exadata DB system to the cloud Exadata infrastructure model. All related resources will be migrated.
     *
     * @param MigrateExadataDbSystemResourceModelRequest
     * @return MigrateExadataDbSystemResourceModelResponse
     * @throws OciError when an error occurs
     */
    migrateExadataDbSystemResourceModel(migrateExadataDbSystemResourceModelRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#migrateExadataDbSystemResourceModel.");
            const pathParams = {
                "{dbSystemId}": migrateExadataDbSystemResourceModelRequest.dbSystemId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": migrateExadataDbSystemResourceModelRequest.opcRequestId,
                "if-match": migrateExadataDbSystemResourceModelRequest.ifMatch,
                "opc-retry-token": migrateExadataDbSystemResourceModelRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}/actions/migration",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, migrateExadataDbSystemResourceModelRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "exadataDbSystemMigration",
                    bodyModel: "model.ExadataDbSystemMigration",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Asynchronously registers this Autonomous Database with Data Safe.
     *
     * @param RegisterAutonomousDatabaseDataSafeRequest
     * @return RegisterAutonomousDatabaseDataSafeResponse
     * @throws OciError when an error occurs
     */
    registerAutonomousDatabaseDataSafe(registerAutonomousDatabaseDataSafeRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#registerAutonomousDatabaseDataSafe.");
            const pathParams = {
                "{autonomousDatabaseId}": registerAutonomousDatabaseDataSafeRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": registerAutonomousDatabaseDataSafeRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/registerDataSafe",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(registerAutonomousDatabaseDataSafeRequest.registerAutonomousDatabaseDataSafeDetails, "RegisterAutonomousDatabaseDataSafeDetails", models.RegisterAutonomousDatabaseDataSafeDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, registerAutonomousDatabaseDataSafeRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Reinstates a disabled standby Autonomous Container Database, identified by the autonomousContainerDatabaseId parameter, to an active standby Autonomous Container Database.
     *
     * @param ReinstateAutonomousContainerDatabaseDataguardAssociationRequest
     * @return ReinstateAutonomousContainerDatabaseDataguardAssociationResponse
     * @throws OciError when an error occurs
     */
    reinstateAutonomousContainerDatabaseDataguardAssociation(reinstateAutonomousContainerDatabaseDataguardAssociationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#reinstateAutonomousContainerDatabaseDataguardAssociation.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": reinstateAutonomousContainerDatabaseDataguardAssociationRequest.autonomousContainerDatabaseId,
                "{autonomousContainerDatabaseDataguardAssociationId}": reinstateAutonomousContainerDatabaseDataguardAssociationRequest.autonomousContainerDatabaseDataguardAssociationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": reinstateAutonomousContainerDatabaseDataguardAssociationRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}/autonomousContainerDatabaseDataguardAssociations/{autonomousContainerDatabaseDataguardAssociationId}/actions/reinstate",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, reinstateAutonomousContainerDatabaseDataguardAssociationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousContainerDatabaseDataguardAssociation",
                    bodyModel: "model.AutonomousContainerDatabaseDataguardAssociation",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Reinstates the database identified by the `databaseId` parameter into the standby role in a Data Guard association.
     *
     * @param ReinstateDataGuardAssociationRequest
     * @return ReinstateDataGuardAssociationResponse
     * @throws OciError when an error occurs
     */
    reinstateDataGuardAssociation(reinstateDataGuardAssociationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#reinstateDataGuardAssociation.");
            const pathParams = {
                "{databaseId}": reinstateDataGuardAssociationRequest.databaseId,
                "{dataGuardAssociationId}": reinstateDataGuardAssociationRequest.dataGuardAssociationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": reinstateDataGuardAssociationRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}/dataGuardAssociations/{dataGuardAssociationId}/actions/reinstate",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(reinstateDataGuardAssociationRequest.reinstateDataGuardAssociationDetails, "ReinstateDataGuardAssociationDetails", models.ReinstateDataGuardAssociationDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, reinstateDataGuardAssociationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dataGuardAssociation",
                    bodyModel: "model.DataGuardAssociation",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Rolling restarts the specified Autonomous Container Database.
     *
     * @param RestartAutonomousContainerDatabaseRequest
     * @return RestartAutonomousContainerDatabaseResponse
     * @throws OciError when an error occurs
     */
    restartAutonomousContainerDatabase(restartAutonomousContainerDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#restartAutonomousContainerDatabase.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": restartAutonomousContainerDatabaseRequest.autonomousContainerDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": restartAutonomousContainerDatabaseRequest.ifMatch,
                "opc-request-id": restartAutonomousContainerDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}/actions/restart",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, restartAutonomousContainerDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousContainerDatabase",
                    bodyModel: "model.AutonomousContainerDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Restarts the specified Autonomous Database.
     *
     * @param RestartAutonomousDatabaseRequest
     * @return RestartAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     */
    restartAutonomousDatabase(restartAutonomousDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#restartAutonomousDatabase.");
            const pathParams = {
                "{autonomousDatabaseId}": restartAutonomousDatabaseRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": restartAutonomousDatabaseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/restart",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, restartAutonomousDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * **Deprecated.** To restore an Autonomous Data Warehouse, use the {@link #restoreAutonomousDatabase(RestoreAutonomousDatabaseRequest) restoreAutonomousDatabase} operation.
     *
     * @param RestoreAutonomousDataWarehouseRequest
     * @return RestoreAutonomousDataWarehouseResponse
     * @throws OciError when an error occurs
     */
    restoreAutonomousDataWarehouse(restoreAutonomousDataWarehouseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#restoreAutonomousDataWarehouse.");
            const pathParams = {
                "{autonomousDataWarehouseId}": restoreAutonomousDataWarehouseRequest.autonomousDataWarehouseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": restoreAutonomousDataWarehouseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouses/{autonomousDataWarehouseId}/actions/restore",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(restoreAutonomousDataWarehouseRequest.restoreAutonomousDataWarehouseDetails, "RestoreAutonomousDataWarehouseDetails", models.RestoreAutonomousDataWarehouseDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, restoreAutonomousDataWarehouseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDataWarehouse",
                    bodyModel: "model.AutonomousDataWarehouse",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Restores an Autonomous Database based on the provided request parameters.
     *
     * @param RestoreAutonomousDatabaseRequest
     * @return RestoreAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     */
    restoreAutonomousDatabase(restoreAutonomousDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#restoreAutonomousDatabase.");
            const pathParams = {
                "{autonomousDatabaseId}": restoreAutonomousDatabaseRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": restoreAutonomousDatabaseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/restore",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(restoreAutonomousDatabaseRequest.restoreAutonomousDatabaseDetails, "RestoreAutonomousDatabaseDetails", models.RestoreAutonomousDatabaseDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, restoreAutonomousDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Restore a Database based on the request parameters you provide.
     *
     * @param RestoreDatabaseRequest
     * @return RestoreDatabaseResponse
     * @throws OciError when an error occurs
     */
    restoreDatabase(restoreDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#restoreDatabase.");
            const pathParams = {
                "{databaseId}": restoreDatabaseRequest.databaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": restoreDatabaseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}/actions/restore",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(restoreDatabaseRequest.restoreDatabaseDetails, "RestoreDatabaseDetails", models.RestoreDatabaseDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, restoreDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "database",
                    bodyModel: "model.Database",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Creates a new version of an existing [Vault service](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm) key.
     * @param RotateAutonomousContainerDatabaseEncryptionKeyRequest
     * @return RotateAutonomousContainerDatabaseEncryptionKeyResponse
     * @throws OciError when an error occurs
     */
    rotateAutonomousContainerDatabaseEncryptionKey(rotateAutonomousContainerDatabaseEncryptionKeyRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#rotateAutonomousContainerDatabaseEncryptionKey.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": rotateAutonomousContainerDatabaseEncryptionKeyRequest.autonomousContainerDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": rotateAutonomousContainerDatabaseEncryptionKeyRequest.ifMatch,
                "opc-retry-token": rotateAutonomousContainerDatabaseEncryptionKeyRequest.opcRetryToken,
                "opc-request-id": rotateAutonomousContainerDatabaseEncryptionKeyRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}/actions/rotateKey",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, rotateAutonomousContainerDatabaseEncryptionKeyRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousContainerDatabase",
                    bodyModel: "model.AutonomousContainerDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Rotate existing AutonomousDatabase [Vault service](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm) key.
     * @param RotateAutonomousDatabaseEncryptionKeyRequest
     * @return RotateAutonomousDatabaseEncryptionKeyResponse
     * @throws OciError when an error occurs
     */
    rotateAutonomousDatabaseEncryptionKey(rotateAutonomousDatabaseEncryptionKeyRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#rotateAutonomousDatabaseEncryptionKey.");
            const pathParams = {
                "{autonomousDatabaseId}": rotateAutonomousDatabaseEncryptionKeyRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": rotateAutonomousDatabaseEncryptionKeyRequest.ifMatch,
                "opc-retry-token": rotateAutonomousDatabaseEncryptionKeyRequest.opcRetryToken,
                "opc-request-id": rotateAutonomousDatabaseEncryptionKeyRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/rotateKey",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, rotateAutonomousDatabaseEncryptionKeyRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * **Deprecated.** To start an Autonomous Data Warehouse, use the {@link #startAutonomousDatabase(StartAutonomousDatabaseRequest) startAutonomousDatabase} operation.
     *
     * @param StartAutonomousDataWarehouseRequest
     * @return StartAutonomousDataWarehouseResponse
     * @throws OciError when an error occurs
     */
    startAutonomousDataWarehouse(startAutonomousDataWarehouseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#startAutonomousDataWarehouse.");
            const pathParams = {
                "{autonomousDataWarehouseId}": startAutonomousDataWarehouseRequest.autonomousDataWarehouseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": startAutonomousDataWarehouseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouses/{autonomousDataWarehouseId}/actions/start",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, startAutonomousDataWarehouseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDataWarehouse",
                    bodyModel: "model.AutonomousDataWarehouse",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Starts the specified Autonomous Database.
     *
     * @param StartAutonomousDatabaseRequest
     * @return StartAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     */
    startAutonomousDatabase(startAutonomousDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#startAutonomousDatabase.");
            const pathParams = {
                "{autonomousDatabaseId}": startAutonomousDatabaseRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": startAutonomousDatabaseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/start",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, startAutonomousDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * **Deprecated.** To stop an Autonomous Data Warehouse, use the {@link #stopAutonomousDatabase(StopAutonomousDatabaseRequest) stopAutonomousDatabase} operation.
     *
     * @param StopAutonomousDataWarehouseRequest
     * @return StopAutonomousDataWarehouseResponse
     * @throws OciError when an error occurs
     */
    stopAutonomousDataWarehouse(stopAutonomousDataWarehouseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#stopAutonomousDataWarehouse.");
            const pathParams = {
                "{autonomousDataWarehouseId}": stopAutonomousDataWarehouseRequest.autonomousDataWarehouseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": stopAutonomousDataWarehouseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouses/{autonomousDataWarehouseId}/actions/stop",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, stopAutonomousDataWarehouseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDataWarehouse",
                    bodyModel: "model.AutonomousDataWarehouse",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Stops the specified Autonomous Database.
     *
     * @param StopAutonomousDatabaseRequest
     * @return StopAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     */
    stopAutonomousDatabase(stopAutonomousDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#stopAutonomousDatabase.");
            const pathParams = {
                "{autonomousDatabaseId}": stopAutonomousDatabaseRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": stopAutonomousDatabaseRequest.ifMatch,
                "opc-request-id": stopAutonomousDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/stop",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, stopAutonomousDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
       * Switches over the primary Autonomous Container Database of an Autonomous Data Guard peer association into a standby role. The standby Autonomous Container Database associated with autonomousContainerDatabaseDataguardAssociationId assumes the primary Autonomous Container Database role.
  * <p>
  A switchover incurs no data loss.
  *
       * @param SwitchoverAutonomousContainerDatabaseDataguardAssociationRequest
       * @return SwitchoverAutonomousContainerDatabaseDataguardAssociationResponse
       * @throws OciError when an error occurs
       */
    switchoverAutonomousContainerDatabaseDataguardAssociation(switchoverAutonomousContainerDatabaseDataguardAssociationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#switchoverAutonomousContainerDatabaseDataguardAssociation.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": switchoverAutonomousContainerDatabaseDataguardAssociationRequest.autonomousContainerDatabaseId,
                "{autonomousContainerDatabaseDataguardAssociationId}": switchoverAutonomousContainerDatabaseDataguardAssociationRequest.autonomousContainerDatabaseDataguardAssociationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": switchoverAutonomousContainerDatabaseDataguardAssociationRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}/autonomousContainerDatabaseDataguardAssociations/{autonomousContainerDatabaseDataguardAssociationId}/actions/switchover",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, switchoverAutonomousContainerDatabaseDataguardAssociationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousContainerDatabaseDataguardAssociation",
                    bodyModel: "model.AutonomousContainerDatabaseDataguardAssociation",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Initiates a switchover of the specified Autonomous Database to the associated standby database. Applicable only to databases with Autonomous Data Guard enabled.
     *
     * @param SwitchoverAutonomousDatabaseRequest
     * @return SwitchoverAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     */
    switchoverAutonomousDatabase(switchoverAutonomousDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#switchoverAutonomousDatabase.");
            const pathParams = {
                "{autonomousDatabaseId}": switchoverAutonomousDatabaseRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": switchoverAutonomousDatabaseRequest.ifMatch,
                "opc-retry-token": switchoverAutonomousDatabaseRequest.opcRetryToken,
                "opc-request-id": switchoverAutonomousDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/actions/switchover",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, switchoverAutonomousDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
       * Performs a switchover to transition the primary database of a Data Guard association into a standby role. The
  * standby database associated with the `dataGuardAssociationId` assumes the primary database role.
  * <p>
  A switchover guarantees no data loss.
  *
       * @param SwitchoverDataGuardAssociationRequest
       * @return SwitchoverDataGuardAssociationResponse
       * @throws OciError when an error occurs
       */
    switchoverDataGuardAssociation(switchoverDataGuardAssociationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#switchoverDataGuardAssociation.");
            const pathParams = {
                "{databaseId}": switchoverDataGuardAssociationRequest.databaseId,
                "{dataGuardAssociationId}": switchoverDataGuardAssociationRequest.dataGuardAssociationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": switchoverDataGuardAssociationRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}/dataGuardAssociations/{dataGuardAssociationId}/actions/switchover",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(switchoverDataGuardAssociationRequest.switchoverDataGuardAssociationDetails, "SwitchoverDataGuardAssociationDetails", models.SwitchoverDataGuardAssociationDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, switchoverDataGuardAssociationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dataGuardAssociation",
                    bodyModel: "model.DataGuardAssociation",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Terminates an Autonomous Container Database, which permanently deletes the container database and any databases within the container database. The database data is local to the Autonomous Exadata Infrastructure and will be lost when the container database is terminated. Oracle recommends that you back up any data in the Autonomous Container Database prior to terminating it.
     * @param TerminateAutonomousContainerDatabaseRequest
     * @return TerminateAutonomousContainerDatabaseResponse
     * @throws OciError when an error occurs
     */
    terminateAutonomousContainerDatabase(terminateAutonomousContainerDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#terminateAutonomousContainerDatabase.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": terminateAutonomousContainerDatabaseRequest.autonomousContainerDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": terminateAutonomousContainerDatabaseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, terminateAutonomousContainerDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Terminates an Autonomous Exadata Infrastructure, which permanently deletes the infrastructure resource and any container databases and databases contained in the resource. The database data is local to the Autonomous Exadata Infrastructure and will be lost when the system is terminated. Oracle recommends that you back up any data in the Autonomous Exadata Infrastructure prior to terminating it.
     * @param TerminateAutonomousExadataInfrastructureRequest
     * @return TerminateAutonomousExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    terminateAutonomousExadataInfrastructure(terminateAutonomousExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#terminateAutonomousExadataInfrastructure.");
            const pathParams = {
                "{autonomousExadataInfrastructureId}": terminateAutonomousExadataInfrastructureRequest.autonomousExadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": terminateAutonomousExadataInfrastructureRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousExadataInfrastructures/{autonomousExadataInfrastructureId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, terminateAutonomousExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Terminates a DB system and permanently deletes it and any databases running on it, and any storage volumes attached to it. The database data is local to the DB system and will be lost when the system is terminated. Oracle recommends that you back up any data in the DB system prior to terminating it.
     * @param TerminateDbSystemRequest
     * @return TerminateDbSystemResponse
     * @throws OciError when an error occurs
     */
    terminateDbSystem(terminateDbSystemRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#terminateDbSystem.");
            const pathParams = {
                "{dbSystemId}": terminateDbSystemRequest.dbSystemId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": terminateDbSystemRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}",
                method: "DELETE",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, terminateDbSystemRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the properties of an Autonomous Container Database, such as the OCPU core count and storage size.
     * @param UpdateAutonomousContainerDatabaseRequest
     * @return UpdateAutonomousContainerDatabaseResponse
     * @throws OciError when an error occurs
     */
    updateAutonomousContainerDatabase(updateAutonomousContainerDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateAutonomousContainerDatabase.");
            const pathParams = {
                "{autonomousContainerDatabaseId}": updateAutonomousContainerDatabaseRequest.autonomousContainerDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateAutonomousContainerDatabaseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousContainerDatabases/{autonomousContainerDatabaseId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateAutonomousContainerDatabaseRequest.updateAutonomousContainerDatabaseDetails, "UpdateAutonomousContainerDatabaseDetails", models.UpdateAutonomousContainerDatabaseDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateAutonomousContainerDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousContainerDatabase",
                    bodyModel: "model.AutonomousContainerDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * **Deprecated.** To update the CPU core count and storage size of an Autonomous Data Warehouse, use the {@link #updateAutonomousDatabase(UpdateAutonomousDatabaseRequest) updateAutonomousDatabase} operation.
     *
     * @param UpdateAutonomousDataWarehouseRequest
     * @return UpdateAutonomousDataWarehouseResponse
     * @throws OciError when an error occurs
     */
    updateAutonomousDataWarehouse(updateAutonomousDataWarehouseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateAutonomousDataWarehouse.");
            const pathParams = {
                "{autonomousDataWarehouseId}": updateAutonomousDataWarehouseRequest.autonomousDataWarehouseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateAutonomousDataWarehouseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDataWarehouses/{autonomousDataWarehouseId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateAutonomousDataWarehouseRequest.updateAutonomousDataWarehouseDetails, "UpdateAutonomousDataWarehouseDetails", models.UpdateAutonomousDataWarehouseDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateAutonomousDataWarehouseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDataWarehouse",
                    bodyModel: "model.AutonomousDataWarehouse",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates one or more attributes of the specified Autonomous Database. See the UpdateAutonomousDatabaseDetails resource for a full list of attributes that can be updated.
     *
     * @param UpdateAutonomousDatabaseRequest
     * @return UpdateAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     */
    updateAutonomousDatabase(updateAutonomousDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateAutonomousDatabase.");
            const pathParams = {
                "{autonomousDatabaseId}": updateAutonomousDatabaseRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateAutonomousDatabaseRequest.ifMatch,
                "opc-request-id": updateAutonomousDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateAutonomousDatabaseRequest.updateAutonomousDatabaseDetails, "UpdateAutonomousDatabaseDetails", models.UpdateAutonomousDatabaseDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateAutonomousDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousDatabase",
                    bodyModel: "model.AutonomousDatabase",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the Autonomous Database regional wallet.
     *
     * @param UpdateAutonomousDatabaseRegionalWalletRequest
     * @return UpdateAutonomousDatabaseRegionalWalletResponse
     * @throws OciError when an error occurs
     */
    updateAutonomousDatabaseRegionalWallet(updateAutonomousDatabaseRegionalWalletRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateAutonomousDatabaseRegionalWallet.");
            const pathParams = {};
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": updateAutonomousDatabaseRegionalWalletRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/wallet",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateAutonomousDatabaseRegionalWalletRequest.updateAutonomousDatabaseWalletDetails, "UpdateAutonomousDatabaseWalletDetails", models.UpdateAutonomousDatabaseWalletDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateAutonomousDatabaseRegionalWalletRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the wallet for the specified Autonomous Database.
     *
     * @param UpdateAutonomousDatabaseWalletRequest
     * @return UpdateAutonomousDatabaseWalletResponse
     * @throws OciError when an error occurs
     */
    updateAutonomousDatabaseWallet(updateAutonomousDatabaseWalletRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateAutonomousDatabaseWallet.");
            const pathParams = {
                "{autonomousDatabaseId}": updateAutonomousDatabaseWalletRequest.autonomousDatabaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": updateAutonomousDatabaseWalletRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousDatabases/{autonomousDatabaseId}/wallet",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateAutonomousDatabaseWalletRequest.updateAutonomousDatabaseWalletDetails, "UpdateAutonomousDatabaseWalletDetails", models.UpdateAutonomousDatabaseWalletDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateAutonomousDatabaseWalletRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the properties of an Autonomous Exadata Infrastructure, such as the CPU core count.
     * @param UpdateAutonomousExadataInfrastructureRequest
     * @return UpdateAutonomousExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    updateAutonomousExadataInfrastructure(updateAutonomousExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateAutonomousExadataInfrastructure.");
            const pathParams = {
                "{autonomousExadataInfrastructureId}": updateAutonomousExadataInfrastructureRequest.autonomousExadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateAutonomousExadataInfrastructureRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousExadataInfrastructures/{autonomousExadataInfrastructureId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateAutonomousExadataInfrastructureRequest.updateAutonomousExadataInfrastructuresDetails, "UpdateAutonomousExadataInfrastructureDetails", models.UpdateAutonomousExadataInfrastructureDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateAutonomousExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousExadataInfrastructure",
                    bodyModel: "model.AutonomousExadataInfrastructure",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the specified Autonomous VM cluster for the Exadata Cloud@Customer system.
     *
     * @param UpdateAutonomousVmClusterRequest
     * @return UpdateAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     */
    updateAutonomousVmCluster(updateAutonomousVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateAutonomousVmCluster.");
            const pathParams = {
                "{autonomousVmClusterId}": updateAutonomousVmClusterRequest.autonomousVmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateAutonomousVmClusterRequest.ifMatch,
                "opc-request-id": updateAutonomousVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/autonomousVmClusters/{autonomousVmClusterId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateAutonomousVmClusterRequest.updateAutonomousVmClusterDetails, "UpdateAutonomousVmClusterDetails", models.UpdateAutonomousVmClusterDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateAutonomousVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "autonomousVmCluster",
                    bodyModel: "model.AutonomousVmCluster",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * If no database is associated with the backup destination:
     * - For a RECOVERY_APPLIANCE backup destination, updates the connection string and/or the list of VPC users.
     * - For an NFS backup destination, updates the NFS location.
     *
     * @param UpdateBackupDestinationRequest
     * @return UpdateBackupDestinationResponse
     * @throws OciError when an error occurs
     */
    updateBackupDestination(updateBackupDestinationRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateBackupDestination.");
            const pathParams = {
                "{backupDestinationId}": updateBackupDestinationRequest.backupDestinationId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateBackupDestinationRequest.ifMatch,
                "opc-request-id": updateBackupDestinationRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/backupDestinations/{backupDestinationId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateBackupDestinationRequest.updateBackupDestinationDetails, "UpdateBackupDestinationDetails", models.UpdateBackupDestinationDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateBackupDestinationRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "backupDestination",
                    bodyModel: "model.BackupDestination",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the Cloud Exadata infrastructure resource.
     *
     * @param UpdateCloudExadataInfrastructureRequest
     * @return UpdateCloudExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    updateCloudExadataInfrastructure(updateCloudExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateCloudExadataInfrastructure.");
            const pathParams = {
                "{cloudExadataInfrastructureId}": updateCloudExadataInfrastructureRequest.cloudExadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateCloudExadataInfrastructureRequest.ifMatch,
                "opc-request-id": updateCloudExadataInfrastructureRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudExadataInfrastructures/{cloudExadataInfrastructureId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateCloudExadataInfrastructureRequest.updateCloudExadataInfrastructureDetails, "UpdateCloudExadataInfrastructureDetails", models.UpdateCloudExadataInfrastructureDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateCloudExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "cloudExadataInfrastructure",
                    bodyModel: "model.CloudExadataInfrastructure",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the specified cloud VM cluster.
     *
     * @param UpdateCloudVmClusterRequest
     * @return UpdateCloudVmClusterResponse
     * @throws OciError when an error occurs
     */
    updateCloudVmCluster(updateCloudVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateCloudVmCluster.");
            const pathParams = {
                "{cloudVmClusterId}": updateCloudVmClusterRequest.cloudVmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateCloudVmClusterRequest.ifMatch,
                "opc-request-id": updateCloudVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters/{cloudVmClusterId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateCloudVmClusterRequest.updateCloudVmClusterDetails, "UpdateCloudVmClusterDetails", models.UpdateCloudVmClusterDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateCloudVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "cloudVmCluster",
                    bodyModel: "model.CloudVmCluster",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the IORM settings for the specified cloud VM cluster.
     *
     * @param UpdateCloudVmClusterIormConfigRequest
     * @return UpdateCloudVmClusterIormConfigResponse
     * @throws OciError when an error occurs
     */
    updateCloudVmClusterIormConfig(updateCloudVmClusterIormConfigRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateCloudVmClusterIormConfig.");
            const pathParams = {
                "{cloudVmClusterId}": updateCloudVmClusterIormConfigRequest.cloudVmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": updateCloudVmClusterIormConfigRequest.opcRequestId,
                "if-match": updateCloudVmClusterIormConfigRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/cloudVmClusters/{cloudVmClusterId}/CloudVmClusterIormConfig",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateCloudVmClusterIormConfigRequest.cloudVmClusterIormConfigUpdateDetails, "ExadataIormConfigUpdateDetails", models.ExadataIormConfigUpdateDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateCloudVmClusterIormConfigRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "exadataIormConfig",
                    bodyModel: "model.ExadataIormConfig",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Update the specified database based on the request parameters provided.
     *
     * @param UpdateDatabaseRequest
     * @return UpdateDatabaseResponse
     * @throws OciError when an error occurs
     */
    updateDatabase(updateDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateDatabase.");
            const pathParams = {
                "{databaseId}": updateDatabaseRequest.databaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateDatabaseRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateDatabaseRequest.updateDatabaseDetails, "UpdateDatabaseDetails", models.UpdateDatabaseDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "database",
                    bodyModel: "model.Database",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the properties of a Database Software Image, like Display Nmae
     * @param UpdateDatabaseSoftwareImageRequest
     * @return UpdateDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     */
    updateDatabaseSoftwareImage(updateDatabaseSoftwareImageRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateDatabaseSoftwareImage.");
            const pathParams = {
                "{databaseSoftwareImageId}": updateDatabaseSoftwareImageRequest.databaseSoftwareImageId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateDatabaseSoftwareImageRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databaseSoftwareImages/{databaseSoftwareImageId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateDatabaseSoftwareImageRequest.updateDatabaseSoftwareImageDetails, "UpdateDatabaseSoftwareImageDetails", models.UpdateDatabaseSoftwareImageDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateDatabaseSoftwareImageRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "databaseSoftwareImage",
                    bodyModel: "model.DatabaseSoftwareImage",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Patches the specified Database Home.
     * @param UpdateDbHomeRequest
     * @return UpdateDbHomeResponse
     * @throws OciError when an error occurs
     */
    updateDbHome(updateDbHomeRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateDbHome.");
            const pathParams = {
                "{dbHomeId}": updateDbHomeRequest.dbHomeId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateDbHomeRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbHomes/{dbHomeId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateDbHomeRequest.updateDbHomeDetails, "UpdateDbHomeDetails", models.UpdateDbHomeDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateDbHomeRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dbHome",
                    bodyModel: "model.DbHome",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the properties of the specified DB system.
     * @param UpdateDbSystemRequest
     * @return UpdateDbSystemResponse
     * @throws OciError when an error occurs
     */
    updateDbSystem(updateDbSystemRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateDbSystem.");
            const pathParams = {
                "{dbSystemId}": updateDbSystemRequest.dbSystemId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateDbSystemRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateDbSystemRequest.updateDbSystemDetails, "UpdateDbSystemDetails", models.UpdateDbSystemDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateDbSystemRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "dbSystem",
                    bodyModel: "model.DbSystem",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the Exadata Cloud@Customer infrastructure.
     *
     * @param UpdateExadataInfrastructureRequest
     * @return UpdateExadataInfrastructureResponse
     * @throws OciError when an error occurs
     */
    updateExadataInfrastructure(updateExadataInfrastructureRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateExadataInfrastructure.");
            const pathParams = {
                "{exadataInfrastructureId}": updateExadataInfrastructureRequest.exadataInfrastructureId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateExadataInfrastructureRequest.ifMatch,
                "opc-request-id": updateExadataInfrastructureRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateExadataInfrastructureRequest.updateExadataInfrastructureDetails, "UpdateExadataInfrastructureDetails", models.UpdateExadataInfrastructureDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateExadataInfrastructureRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "exadataInfrastructure",
                    bodyModel: "model.ExadataInfrastructure",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates IORM settings for the specified Exadata system.
     *
     * @param UpdateExadataIormConfigRequest
     * @return UpdateExadataIormConfigResponse
     * @throws OciError when an error occurs
     */
    updateExadataIormConfig(updateExadataIormConfigRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateExadataIormConfig.");
            const pathParams = {
                "{dbSystemId}": updateExadataIormConfigRequest.dbSystemId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": updateExadataIormConfigRequest.opcRequestId,
                "if-match": updateExadataIormConfigRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/dbSystems/{dbSystemId}/ExadataIormConfig",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateExadataIormConfigRequest.exadataIormConfigUpdateDetails, "ExadataIormConfigUpdateDetails", models.ExadataIormConfigUpdateDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateExadataIormConfigRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "exadataIormConfig",
                    bodyModel: "model.ExadataIormConfig",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * If no database is associated with the key store, edit the key store.
     *
     * @param UpdateKeyStoreRequest
     * @return UpdateKeyStoreResponse
     * @throws OciError when an error occurs
     */
    updateKeyStore(updateKeyStoreRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateKeyStore.");
            const pathParams = {
                "{keyStoreId}": updateKeyStoreRequest.keyStoreId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateKeyStoreRequest.ifMatch,
                "opc-request-id": updateKeyStoreRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/keyStores/{keyStoreId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateKeyStoreRequest.updateKeyStoreDetails, "UpdateKeyStoreDetails", models.UpdateKeyStoreDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateKeyStoreRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "keyStore",
                    bodyModel: "model.KeyStore",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the properties of a maintenance run, such as the state of a maintenance run.
     * @param UpdateMaintenanceRunRequest
     * @return UpdateMaintenanceRunResponse
     * @throws OciError when an error occurs
     */
    updateMaintenanceRun(updateMaintenanceRunRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateMaintenanceRun.");
            const pathParams = {
                "{maintenanceRunId}": updateMaintenanceRunRequest.maintenanceRunId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateMaintenanceRunRequest.ifMatch
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/maintenanceRuns/{maintenanceRunId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateMaintenanceRunRequest.updateMaintenanceRunDetails, "UpdateMaintenanceRunDetails", models.UpdateMaintenanceRunDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateMaintenanceRunRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "maintenanceRun",
                    bodyModel: "model.MaintenanceRun",
                    responseHeaders: [
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the specified Exadata Cloud@Customer VM cluster.
     *
     * @param UpdateVmClusterRequest
     * @return UpdateVmClusterResponse
     * @throws OciError when an error occurs
     */
    updateVmCluster(updateVmClusterRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateVmCluster.");
            const pathParams = {
                "{vmClusterId}": updateVmClusterRequest.vmClusterId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateVmClusterRequest.ifMatch,
                "opc-request-id": updateVmClusterRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/vmClusters/{vmClusterId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateVmClusterRequest.updateVmClusterDetails, "UpdateVmClusterDetails", models.UpdateVmClusterDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateVmClusterRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "vmCluster",
                    bodyModel: "model.VmCluster",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Updates the specified Exadata Cloud@Customer VM cluster network.
     *
     * @param UpdateVmClusterNetworkRequest
     * @return UpdateVmClusterNetworkResponse
     * @throws OciError when an error occurs
     */
    updateVmClusterNetwork(updateVmClusterNetworkRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#updateVmClusterNetwork.");
            const pathParams = {
                "{exadataInfrastructureId}": updateVmClusterNetworkRequest.exadataInfrastructureId,
                "{vmClusterNetworkId}": updateVmClusterNetworkRequest.vmClusterNetworkId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": updateVmClusterNetworkRequest.ifMatch,
                "opc-request-id": updateVmClusterNetworkRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/vmClusterNetworks/{vmClusterNetworkId}",
                method: "PUT",
                bodyContent: common.ObjectSerializer.serialize(updateVmClusterNetworkRequest.updateVmClusterNetworkDetails, "UpdateVmClusterNetworkDetails", models.UpdateVmClusterNetworkDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, updateVmClusterNetworkRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "vmClusterNetwork",
                    bodyModel: "model.VmClusterNetwork",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Upgrade the specified database.
     *
     * @param UpgradeDatabaseRequest
     * @return UpgradeDatabaseResponse
     * @throws OciError when an error occurs
     */
    upgradeDatabase(upgradeDatabaseRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#upgradeDatabase.");
            const pathParams = {
                "{databaseId}": upgradeDatabaseRequest.databaseId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "if-match": upgradeDatabaseRequest.ifMatch,
                "opc-request-id": upgradeDatabaseRequest.opcRequestId
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/databases/{databaseId}/actions/upgrade",
                method: "POST",
                bodyContent: common.ObjectSerializer.serialize(upgradeDatabaseRequest.upgradeDatabaseDetails, "UpgradeDatabaseDetails", models.UpgradeDatabaseDetails.getJsonObj),
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, upgradeDatabaseRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "database",
                    bodyModel: "model.Database",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
    /**
     * Validates the specified Exadata Cloud@Customer VM cluster network.
     *
     * @param ValidateVmClusterNetworkRequest
     * @return ValidateVmClusterNetworkResponse
     * @throws OciError when an error occurs
     */
    validateVmClusterNetwork(validateVmClusterNetworkRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.logger)
                this.logger.debug("Calling operation DatabaseClient#validateVmClusterNetwork.");
            const pathParams = {
                "{exadataInfrastructureId}": validateVmClusterNetworkRequest.exadataInfrastructureId,
                "{vmClusterNetworkId}": validateVmClusterNetworkRequest.vmClusterNetworkId
            };
            const queryParams = {};
            let headerParams = {
                "Content-Type": common.Constants.APPLICATION_JSON,
                "opc-request-id": validateVmClusterNetworkRequest.opcRequestId,
                "opc-retry-token": validateVmClusterNetworkRequest.opcRetryToken
            };
            const request = yield oci_common_2.composeRequest({
                baseEndpoint: this._endpoint,
                defaultHeaders: this._defaultHeaders,
                path: "/exadataInfrastructures/{exadataInfrastructureId}/vmClusterNetworks/{vmClusterNetworkId}/actions/validate",
                method: "POST",
                pathParams: pathParams,
                headerParams: headerParams,
                queryParams: queryParams
            });
            const retrier = oci_common_2.GenericRetrier.createPreferredRetrier(this._clientConfiguration ? this._clientConfiguration.retryConfiguration : {}, validateVmClusterNetworkRequest.retryConfiguration);
            if (this.logger)
                retrier.logger = this.logger;
            try {
                const response = yield retrier.makeServiceCall(this._httpClient, request);
                const sdkResponse = oci_common_2.composeResponse({
                    responseObject: {},
                    body: yield response.json(),
                    bodyKey: "vmClusterNetwork",
                    bodyModel: "model.VmClusterNetwork",
                    responseHeaders: [
                        {
                            value: response.headers.get("opc-work-request-id"),
                            key: "opcWorkRequestId",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("etag"),
                            key: "etag",
                            dataType: "string"
                        },
                        {
                            value: response.headers.get("opc-request-id"),
                            key: "opcRequestId",
                            dataType: "string"
                        }
                    ]
                });
                return sdkResponse;
            }
            catch (err) {
                throw err;
            }
        });
    }
}
exports.DatabaseClient = DatabaseClient;
DatabaseClient.serviceEndpointTemplate = "https://database.{region}.{secondLevelDomain}";
//# sourceMappingURL=client.js.map